Prompt drop Package Body DML_GVM_AUDITORIA;
DROP PACKAGE BODY GVM_ADM.DML_GVM_AUDITORIA
/

Prompt Package Body DML_GVM_AUDITORIA;
--
-- DML_GVM_AUDITORIA  (Package Body) 
--
--  Dependencies: 
--   DML_GVM_AUDITORIA (Package)
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_AUDITORIA (Table)
--   GVM_LOG_PROCEDIMENTS (Table)
--   DUAL (Synonym)
--   STANDARD (Package)
--
CREATE OR REPLACE PACKAGE BODY GVM_ADM.DML_GVM_AUDITORIA IS

  PROCEDURE INS_GVM_AUDITORIA
    (
     in_ID_AUDITORIA          IN GVM_ADM.GVM_AUDITORIA.ID_AUDITORIA%TYPE
    ,in_NOM_AUDITORIA         IN GVM_ADM.GVM_AUDITORIA.NOM_AUDITORIA%TYPE
    ,in_DESC_AUDITORIA_CAT    IN GVM_ADM.GVM_AUDITORIA.DESC_AUDITORIA_CAT%TYPE
    ,in_DESC_AUDITORIA_CAST   IN GVM_ADM.GVM_AUDITORIA.DESC_AUDITORIA_CAST%TYPE
    ,in_DESC_AUDITORIA_ANG    IN GVM_ADM.GVM_AUDITORIA.DESC_AUDITORIA_ANG%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_AUDITORIA.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_AUDITORIA.FK_USUARI_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_AUDITORIA.DATA_MODIFICACIO%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_AUDITORIA.FK_USUARI_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_AUDITORIA.DATA_BAIXA%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_AUDITORIA.FK_USUARI_BAIXA%TYPE
    ,in_ANY_AUDITORIA         IN GVM_ADM.GVM_AUDITORIA.ANY_AUDITORIA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN
   RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'INS_GVM_AUDITORIA';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
        
    INSERT INTO GVM_ADM.GVM_AUDITORIA
      (
       ID_AUDITORIA
      ,NOM_AUDITORIA
      ,DESC_AUDITORIA_CAT
      ,DESC_AUDITORIA_CAST
      ,DESC_AUDITORIA_ANG
      ,DATA_ALTA
      ,FK_USUARI_ALTA
      ,DATA_MODIFICACIO
      ,FK_USUARI_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_BAIXA
      ,ANY_AUDITORIA
      )
    VALUES
      (
       in_ID_AUDITORIA
      ,in_NOM_AUDITORIA
      ,in_DESC_AUDITORIA_CAT
      ,in_DESC_AUDITORIA_CAST
      ,in_DESC_AUDITORIA_ANG
      ,in_DATA_ALTA
      ,in_FK_USUARI_ALTA
      ,in_DATA_MODIFICACIO
      ,in_FK_USUARI_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_BAIXA
      ,in_ANY_AUDITORIA
      );
      
              l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
                
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END INS_GVM_AUDITORIA;

  PROCEDURE MERGE_GVM_AUDITORIA
    (
     in_ID_AUDITORIA          IN GVM_ADM.GVM_AUDITORIA.ID_AUDITORIA%TYPE
    ,in_NOM_AUDITORIA         IN GVM_ADM.GVM_AUDITORIA.NOM_AUDITORIA%TYPE
    ,in_DESC_AUDITORIA_CAT    IN GVM_ADM.GVM_AUDITORIA.DESC_AUDITORIA_CAT%TYPE
    ,in_DESC_AUDITORIA_CAST   IN GVM_ADM.GVM_AUDITORIA.DESC_AUDITORIA_CAST%TYPE
    ,in_DESC_AUDITORIA_ANG    IN GVM_ADM.GVM_AUDITORIA.DESC_AUDITORIA_ANG%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_AUDITORIA.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_AUDITORIA.FK_USUARI_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_AUDITORIA.DATA_MODIFICACIO%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_AUDITORIA.FK_USUARI_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_AUDITORIA.DATA_BAIXA%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_AUDITORIA.FK_USUARI_BAIXA%TYPE
    ,in_ANY_AUDITORIA         IN GVM_ADM.GVM_AUDITORIA.ANY_AUDITORIA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'MERGE_GVM_AUDITORIA';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
        
    MERGE INTO GVM_ADM.GVM_AUDITORIA A USING
      (SELECT
       in_ID_AUDITORIA as ID_AUDITORIA
      ,in_NOM_AUDITORIA as NOM_AUDITORIA
      ,in_DESC_AUDITORIA_CAT as DESC_AUDITORIA_CAT
      ,in_DESC_AUDITORIA_CAST as DESC_AUDITORIA_CAST
      ,in_DESC_AUDITORIA_ANG as DESC_AUDITORIA_ANG
      ,in_DATA_ALTA as DATA_ALTA
      ,in_FK_USUARI_ALTA as FK_USUARI_ALTA
      ,in_DATA_MODIFICACIO as DATA_MODIFICACIO
      ,in_FK_USUARI_MODIFICACIO as FK_USUARI_MODIFICACIO
      ,in_DATA_BAIXA as DATA_BAIXA
      ,in_FK_USUARI_BAIXA as FK_USUARI_BAIXA
      ,in_ANY_AUDITORIA as ANY_AUDITORIA
      FROM DUAL) B
    ON (A.ID_AUDITORIA= B.ID_AUDITORIA)
    WHEN NOT MATCHED THEN
      INSERT (
       ID_AUDITORIA
      ,NOM_AUDITORIA
      ,DESC_AUDITORIA_CAT
      ,DESC_AUDITORIA_CAST
      ,DESC_AUDITORIA_ANG
      ,DATA_ALTA
      ,FK_USUARI_ALTA
      ,DATA_MODIFICACIO
      ,FK_USUARI_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_BAIXA
      ,ANY_AUDITORIA)
      VALUES
      (in_ID_AUDITORIA
      ,in_NOM_AUDITORIA
      ,in_DESC_AUDITORIA_CAT
      ,in_DESC_AUDITORIA_CAST
      ,in_DESC_AUDITORIA_ANG
      ,in_DATA_ALTA
      ,in_FK_USUARI_ALTA
      ,in_DATA_MODIFICACIO
      ,in_FK_USUARI_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_BAIXA
      ,in_ANY_AUDITORIA)
    WHEN MATCHED THEN
      UPDATE SET
         A.NOM_AUDITORIA = B.NOM_AUDITORIA
        ,A.DESC_AUDITORIA_CAT = B.DESC_AUDITORIA_CAT
        ,A.DESC_AUDITORIA_CAST = B.DESC_AUDITORIA_CAST
        ,A.DESC_AUDITORIA_ANG = B.DESC_AUDITORIA_ANG
        ,A.DATA_ALTA = B.DATA_ALTA
        ,A.FK_USUARI_ALTA = B.FK_USUARI_ALTA
        ,A.DATA_MODIFICACIO = B.DATA_MODIFICACIO
        ,A.FK_USUARI_MODIFICACIO = B.FK_USUARI_MODIFICACIO
        ,A.DATA_BAIXA = B.DATA_BAIXA
        ,A.FK_USUARI_BAIXA = B.FK_USUARI_BAIXA
        ,A.ANY_AUDITORIA = B.ANY_AUDITORIA;

        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;   
                
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END MERGE_GVM_AUDITORIA;

  PROCEDURE UPD_GVM_AUDITORIA
    (
     in_ID_AUDITORIA          IN GVM_ADM.GVM_AUDITORIA.ID_AUDITORIA%TYPE
    ,in_NOM_AUDITORIA         IN GVM_ADM.GVM_AUDITORIA.NOM_AUDITORIA%TYPE
    ,in_DESC_AUDITORIA_CAT    IN GVM_ADM.GVM_AUDITORIA.DESC_AUDITORIA_CAT%TYPE
    ,in_DESC_AUDITORIA_CAST   IN GVM_ADM.GVM_AUDITORIA.DESC_AUDITORIA_CAST%TYPE
    ,in_DESC_AUDITORIA_ANG    IN GVM_ADM.GVM_AUDITORIA.DESC_AUDITORIA_ANG%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_AUDITORIA.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_AUDITORIA.FK_USUARI_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_AUDITORIA.DATA_MODIFICACIO%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_AUDITORIA.FK_USUARI_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_AUDITORIA.DATA_BAIXA%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_AUDITORIA.FK_USUARI_BAIXA%TYPE
    ,in_ANY_AUDITORIA         IN GVM_ADM.GVM_AUDITORIA.ANY_AUDITORIA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'UPD_GVM_AUDITORIA';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    UPDATE GVM_ADM.GVM_AUDITORIA
    SET 
        NOM_AUDITORIA           = in_NOM_AUDITORIA
       ,DESC_AUDITORIA_CAT      = in_DESC_AUDITORIA_CAT
       ,DESC_AUDITORIA_CAST     = in_DESC_AUDITORIA_CAST
       ,DESC_AUDITORIA_ANG      = in_DESC_AUDITORIA_ANG
       ,DATA_ALTA               = in_DATA_ALTA
       ,FK_USUARI_ALTA          = in_FK_USUARI_ALTA
       ,DATA_MODIFICACIO        = in_DATA_MODIFICACIO
       ,FK_USUARI_MODIFICACIO   = in_FK_USUARI_MODIFICACIO
       ,DATA_BAIXA              = in_DATA_BAIXA
       ,FK_USUARI_BAIXA         = in_FK_USUARI_BAIXA
       ,ANY_AUDITORIA           = in_ANY_AUDITORIA
    WHERE
        ID_AUDITORIA            = in_ID_AUDITORIA;

        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;   
                
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END UPD_GVM_AUDITORIA;

  PROCEDURE DEL_GVM_AUDITORIA
    (
     in_ID_AUDITORIA          IN GVM_ADM.GVM_AUDITORIA.ID_AUDITORIA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'DEL_GVM_AUDITORIA';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='';
  
    DELETE FROM GVM_ADM.GVM_AUDITORIA
    WHERE
        ID_AUDITORIA            = in_ID_AUDITORIA;

        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;   
                        
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
                                   
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END DEL_GVM_AUDITORIA;

END DML_GVM_AUDITORIA;
/
SHOW ERRORS;