Prompt drop Package Body DML_GVM_DEPARTAMENT;
DROP PACKAGE BODY GVM_ADM.DML_GVM_DEPARTAMENT
/

Prompt Package Body DML_GVM_DEPARTAMENT;
--
-- DML_GVM_DEPARTAMENT  (Package Body) 
--
--  Dependencies: 
--   DML_GVM_DEPARTAMENT (Package)
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_DEPARTAMENT (Table)
--   GVM_LOG_PROCEDIMENTS (Table)
--   DUAL (Synonym)
--   STANDARD (Package)
--
CREATE OR REPLACE PACKAGE BODY GVM_ADM.DML_GVM_DEPARTAMENT IS

  PROCEDURE INS_GVM_DEPARTAMENT
    (
     in_ID_DEPARTAMENT        IN GVM_ADM.GVM_DEPARTAMENT.ID_DEPARTAMENT%TYPE
    ,in_NOM_DEPARTAMENT       IN GVM_ADM.GVM_DEPARTAMENT.NOM_DEPARTAMENT%TYPE
    ,in_DESC_DEPARTAMENT_CAT  IN GVM_ADM.GVM_DEPARTAMENT.DESC_DEPARTAMENT_CAT%TYPE
    ,in_DESC_DEPARTAMENT_CAST IN GVM_ADM.GVM_DEPARTAMENT.DESC_DEPARTAMENT_CAST%TYPE
    ,in_DESC_DEPARTAMENT_ANG  IN GVM_ADM.GVM_DEPARTAMENT.DESC_DEPARTAMENT_ANG%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_DEPARTAMENT.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_DEPARTAMENT.FK_USUARI_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_DEPARTAMENT.DATA_MODIFICACIO%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_DEPARTAMENT.FK_USUARI_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_DEPARTAMENT.DATA_BAIXA%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_DEPARTAMENT.FK_USUARI_BAIXA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'INS_GVM_DEPARTAMENT';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    INSERT INTO GVM_ADM.GVM_DEPARTAMENT
      (
       ID_DEPARTAMENT
      ,NOM_DEPARTAMENT
      ,DESC_DEPARTAMENT_CAT
      ,DESC_DEPARTAMENT_CAST
      ,DESC_DEPARTAMENT_ANG
      ,DATA_ALTA
      ,FK_USUARI_ALTA
      ,DATA_MODIFICACIO
      ,FK_USUARI_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_BAIXA
      )
    VALUES
      (
       in_ID_DEPARTAMENT
      ,in_NOM_DEPARTAMENT
      ,in_DESC_DEPARTAMENT_CAT
      ,in_DESC_DEPARTAMENT_CAST
      ,in_DESC_DEPARTAMENT_ANG
      ,in_DATA_ALTA
      ,in_FK_USUARI_ALTA
      ,in_DATA_MODIFICACIO
      ,in_FK_USUARI_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_BAIXA
      );
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;   
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END INS_GVM_DEPARTAMENT;

  PROCEDURE MERGE_GVM_DEPARTAMENT
    (
     in_ID_DEPARTAMENT        IN GVM_ADM.GVM_DEPARTAMENT.ID_DEPARTAMENT%TYPE
    ,in_NOM_DEPARTAMENT       IN GVM_ADM.GVM_DEPARTAMENT.NOM_DEPARTAMENT%TYPE
    ,in_DESC_DEPARTAMENT_CAT  IN GVM_ADM.GVM_DEPARTAMENT.DESC_DEPARTAMENT_CAT%TYPE
    ,in_DESC_DEPARTAMENT_CAST IN GVM_ADM.GVM_DEPARTAMENT.DESC_DEPARTAMENT_CAST%TYPE
    ,in_DESC_DEPARTAMENT_ANG  IN GVM_ADM.GVM_DEPARTAMENT.DESC_DEPARTAMENT_ANG%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_DEPARTAMENT.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_DEPARTAMENT.FK_USUARI_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_DEPARTAMENT.DATA_MODIFICACIO%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_DEPARTAMENT.FK_USUARI_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_DEPARTAMENT.DATA_BAIXA%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_DEPARTAMENT.FK_USUARI_BAIXA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'MERGE_GVM_DEPARTAMENT';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    MERGE INTO GVM_ADM.GVM_DEPARTAMENT A USING
      (SELECT
       in_ID_DEPARTAMENT as ID_DEPARTAMENT
      ,in_NOM_DEPARTAMENT as NOM_DEPARTAMENT
      ,in_DESC_DEPARTAMENT_CAT as DESC_DEPARTAMENT_CAT
      ,in_DESC_DEPARTAMENT_CAST as DESC_DEPARTAMENT_CAST
      ,in_DESC_DEPARTAMENT_ANG as DESC_DEPARTAMENT_ANG
      ,in_DATA_ALTA as DATA_ALTA
      ,in_FK_USUARI_ALTA as FK_USUARI_ALTA
      ,in_DATA_MODIFICACIO as DATA_MODIFICACIO
      ,in_FK_USUARI_MODIFICACIO as FK_USUARI_MODIFICACIO
      ,in_DATA_BAIXA as DATA_BAIXA
      ,in_FK_USUARI_BAIXA as FK_USUARI_BAIXA
      FROM DUAL) B
    ON (A.ID_DEPARTAMENT= B.ID_DEPARTAMENT)
    WHEN NOT MATCHED THEN
      INSERT (
       ID_DEPARTAMENT
      ,NOM_DEPARTAMENT
      ,DESC_DEPARTAMENT_CAT
      ,DESC_DEPARTAMENT_CAST
      ,DESC_DEPARTAMENT_ANG
      ,DATA_ALTA
      ,FK_USUARI_ALTA
      ,DATA_MODIFICACIO
      ,FK_USUARI_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_BAIXA)
      VALUES
      (in_ID_DEPARTAMENT
      ,in_NOM_DEPARTAMENT
      ,in_DESC_DEPARTAMENT_CAT
      ,in_DESC_DEPARTAMENT_CAST
      ,in_DESC_DEPARTAMENT_ANG
      ,in_DATA_ALTA
      ,in_FK_USUARI_ALTA
      ,in_DATA_MODIFICACIO
      ,in_FK_USUARI_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_BAIXA)
    WHEN MATCHED THEN
      UPDATE SET
         A.NOM_DEPARTAMENT = B.NOM_DEPARTAMENT
        ,A.DESC_DEPARTAMENT_CAT = B.DESC_DEPARTAMENT_CAT
        ,A.DESC_DEPARTAMENT_CAST = B.DESC_DEPARTAMENT_CAST
        ,A.DESC_DEPARTAMENT_ANG = B.DESC_DEPARTAMENT_ANG
        ,A.DATA_ALTA = B.DATA_ALTA
        ,A.FK_USUARI_ALTA = B.FK_USUARI_ALTA
        ,A.DATA_MODIFICACIO = B.DATA_MODIFICACIO
        ,A.FK_USUARI_MODIFICACIO = B.FK_USUARI_MODIFICACIO
        ,A.DATA_BAIXA = B.DATA_BAIXA
        ,A.FK_USUARI_BAIXA = B.FK_USUARI_BAIXA;
                    l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;       
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END MERGE_GVM_DEPARTAMENT;

  PROCEDURE UPD_GVM_DEPARTAMENT
    (
     in_ID_DEPARTAMENT        IN GVM_ADM.GVM_DEPARTAMENT.ID_DEPARTAMENT%TYPE
    ,in_NOM_DEPARTAMENT       IN GVM_ADM.GVM_DEPARTAMENT.NOM_DEPARTAMENT%TYPE
    ,in_DESC_DEPARTAMENT_CAT  IN GVM_ADM.GVM_DEPARTAMENT.DESC_DEPARTAMENT_CAT%TYPE
    ,in_DESC_DEPARTAMENT_CAST IN GVM_ADM.GVM_DEPARTAMENT.DESC_DEPARTAMENT_CAST%TYPE
    ,in_DESC_DEPARTAMENT_ANG  IN GVM_ADM.GVM_DEPARTAMENT.DESC_DEPARTAMENT_ANG%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_DEPARTAMENT.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_DEPARTAMENT.FK_USUARI_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_DEPARTAMENT.DATA_MODIFICACIO%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_DEPARTAMENT.FK_USUARI_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_DEPARTAMENT.DATA_BAIXA%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_DEPARTAMENT.FK_USUARI_BAIXA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'UPD_GVM_DEPARTAMENT';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    UPDATE GVM_ADM.GVM_DEPARTAMENT
    SET 
        NOM_DEPARTAMENT         = in_NOM_DEPARTAMENT
       ,DESC_DEPARTAMENT_CAT    = in_DESC_DEPARTAMENT_CAT
       ,DESC_DEPARTAMENT_CAST   = in_DESC_DEPARTAMENT_CAST
       ,DESC_DEPARTAMENT_ANG    = in_DESC_DEPARTAMENT_ANG
       ,DATA_ALTA               = in_DATA_ALTA
       ,FK_USUARI_ALTA          = in_FK_USUARI_ALTA
       ,DATA_MODIFICACIO        = in_DATA_MODIFICACIO
       ,FK_USUARI_MODIFICACIO   = in_FK_USUARI_MODIFICACIO
       ,DATA_BAIXA              = in_DATA_BAIXA
       ,FK_USUARI_BAIXA         = in_FK_USUARI_BAIXA
    WHERE
        ID_DEPARTAMENT          = in_ID_DEPARTAMENT;
                      l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;     
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END UPD_GVM_DEPARTAMENT;

  PROCEDURE DEL_GVM_DEPARTAMENT
    (
     in_ID_DEPARTAMENT        IN GVM_ADM.GVM_DEPARTAMENT.ID_DEPARTAMENT%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'DEL_GVM_DEPARTAMENT';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='';
  
    DELETE FROM GVM_ADM.GVM_DEPARTAMENT
    WHERE
        ID_DEPARTAMENT          = in_ID_DEPARTAMENT;
        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;                   
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END DEL_GVM_DEPARTAMENT;

END DML_GVM_DEPARTAMENT;
/
SHOW ERRORS;