Prompt drop Package Body DML_GVM_DEPARTAMENT_PERSONES;
DROP PACKAGE BODY GVM_ADM.DML_GVM_DEPARTAMENT_PERSONES
/

Prompt Package Body DML_GVM_DEPARTAMENT_PERSONES;
--
-- DML_GVM_DEPARTAMENT_PERSONES  (Package Body) 
--
--  Dependencies: 
--   DML_GVM_DEPARTAMENT_PERSONES (Package)
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_DEPARTAMENT_PERSONES (Table)
--   GVM_LOG_PROCEDIMENTS (Table)
--   DUAL (Synonym)
--   STANDARD (Package)
--
CREATE OR REPLACE PACKAGE BODY GVM_ADM.DML_GVM_DEPARTAMENT_PERSONES IS

  PROCEDURE INS_GVM_DEPARTAMENT_PERSONES
    (
     in_ID_DEPARTAMENT_PERSONES IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.ID_DEPARTAMENT_PERSONES%TYPE
    ,in_FK_ID_DEPARTAMENT       IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_ID_DEPARTAMENT%TYPE
    ,in_FK_ID_PERSONA           IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_ID_PERSONA%TYPE
    ,in_DATA_ALTA               IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.DATA_ALTA%TYPE
    ,in_DATA_MODIFICACIO        IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.DATA_MODIFICACIO%TYPE
    ,in_DATA_BAIXA              IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.DATA_BAIXA%TYPE
    ,in_FK_USUARI_ALTA          IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_USUARI_ALTA%TYPE
    ,in_FK_USUARI_MODIFICACIO   IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_USUARI_MODIFICACIO%TYPE
    ,in_FK_USUARI_BAIXA         IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_USUARI_BAIXA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'INS_GVM_DEPARTAMENT_PERSONES';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    INSERT INTO GVM_ADM.GVM_DEPARTAMENT_PERSONES
      (
       ID_DEPARTAMENT_PERSONES
      ,FK_ID_DEPARTAMENT
      ,FK_ID_PERSONA
      ,DATA_ALTA
      ,DATA_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_ALTA
      ,FK_USUARI_MODIFICACIO
      ,FK_USUARI_BAIXA
      )
    VALUES
      (
       in_ID_DEPARTAMENT_PERSONES
      ,in_FK_ID_DEPARTAMENT
      ,in_FK_ID_PERSONA
      ,in_DATA_ALTA
      ,in_DATA_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_ALTA
      ,in_FK_USUARI_MODIFICACIO
      ,in_FK_USUARI_BAIXA
      );
                       l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE; 
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END INS_GVM_DEPARTAMENT_PERSONES;

  PROCEDURE MERGE_GVM_DEPARTAMENT_PERSONES
    (
     in_ID_DEPARTAMENT_PERSONES IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.ID_DEPARTAMENT_PERSONES%TYPE
    ,in_FK_ID_DEPARTAMENT       IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_ID_DEPARTAMENT%TYPE
    ,in_FK_ID_PERSONA           IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_ID_PERSONA%TYPE
    ,in_DATA_ALTA               IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.DATA_ALTA%TYPE
    ,in_DATA_MODIFICACIO        IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.DATA_MODIFICACIO%TYPE
    ,in_DATA_BAIXA              IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.DATA_BAIXA%TYPE
    ,in_FK_USUARI_ALTA          IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_USUARI_ALTA%TYPE
    ,in_FK_USUARI_MODIFICACIO   IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_USUARI_MODIFICACIO%TYPE
    ,in_FK_USUARI_BAIXA         IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_USUARI_BAIXA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'MERGE_GVM_DEPARTAMENT_PERSONES';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    MERGE INTO GVM_ADM.GVM_DEPARTAMENT_PERSONES A USING
      (SELECT
       in_ID_DEPARTAMENT_PERSONES as ID_DEPARTAMENT_PERSONES
      ,in_FK_ID_DEPARTAMENT as FK_ID_DEPARTAMENT
      ,in_FK_ID_PERSONA as FK_ID_PERSONA
      ,in_DATA_ALTA as DATA_ALTA
      ,in_DATA_MODIFICACIO as DATA_MODIFICACIO
      ,in_DATA_BAIXA as DATA_BAIXA
      ,in_FK_USUARI_ALTA as FK_USUARI_ALTA
      ,in_FK_USUARI_MODIFICACIO as FK_USUARI_MODIFICACIO
      ,in_FK_USUARI_BAIXA as FK_USUARI_BAIXA
      FROM DUAL) B
    ON (A.ID_DEPARTAMENT_PERSONES= B.ID_DEPARTAMENT_PERSONES)
    WHEN NOT MATCHED THEN
      INSERT (
       ID_DEPARTAMENT_PERSONES
      ,FK_ID_DEPARTAMENT
      ,FK_ID_PERSONA
      ,DATA_ALTA
      ,DATA_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_ALTA
      ,FK_USUARI_MODIFICACIO
      ,FK_USUARI_BAIXA)
      VALUES
      (in_ID_DEPARTAMENT_PERSONES
      ,in_FK_ID_DEPARTAMENT
      ,in_FK_ID_PERSONA
      ,in_DATA_ALTA
      ,in_DATA_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_ALTA
      ,in_FK_USUARI_MODIFICACIO
      ,in_FK_USUARI_BAIXA)
    WHEN MATCHED THEN
      UPDATE SET
         A.FK_ID_DEPARTAMENT = B.FK_ID_DEPARTAMENT
        ,A.FK_ID_PERSONA = B.FK_ID_PERSONA
        ,A.DATA_ALTA = B.DATA_ALTA
        ,A.DATA_MODIFICACIO = B.DATA_MODIFICACIO
        ,A.DATA_BAIXA = B.DATA_BAIXA
        ,A.FK_USUARI_ALTA = B.FK_USUARI_ALTA
        ,A.FK_USUARI_MODIFICACIO = B.FK_USUARI_MODIFICACIO
        ,A.FK_USUARI_BAIXA = B.FK_USUARI_BAIXA;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END MERGE_GVM_DEPARTAMENT_PERSONES;

  PROCEDURE UPD_GVM_DEPARTAMENT_PERSONES
    (
     in_ID_DEPARTAMENT_PERSONES IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.ID_DEPARTAMENT_PERSONES%TYPE
    ,in_FK_ID_DEPARTAMENT       IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_ID_DEPARTAMENT%TYPE
    ,in_FK_ID_PERSONA           IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_ID_PERSONA%TYPE
    ,in_DATA_ALTA               IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.DATA_ALTA%TYPE
    ,in_DATA_MODIFICACIO        IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.DATA_MODIFICACIO%TYPE
    ,in_DATA_BAIXA              IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.DATA_BAIXA%TYPE
    ,in_FK_USUARI_ALTA          IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_USUARI_ALTA%TYPE
    ,in_FK_USUARI_MODIFICACIO   IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_USUARI_MODIFICACIO%TYPE
    ,in_FK_USUARI_BAIXA         IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.FK_USUARI_BAIXA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'UPD_GVM_DEPARTAMENT_PERSONES';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    UPDATE GVM_ADM.GVM_DEPARTAMENT_PERSONES
    SET 
        FK_ID_DEPARTAMENT         = in_FK_ID_DEPARTAMENT
       ,FK_ID_PERSONA             = in_FK_ID_PERSONA
       ,DATA_ALTA                 = in_DATA_ALTA
       ,DATA_MODIFICACIO          = in_DATA_MODIFICACIO
       ,DATA_BAIXA                = in_DATA_BAIXA
       ,FK_USUARI_ALTA            = in_FK_USUARI_ALTA
       ,FK_USUARI_MODIFICACIO     = in_FK_USUARI_MODIFICACIO
       ,FK_USUARI_BAIXA           = in_FK_USUARI_BAIXA
    WHERE
        ID_DEPARTAMENT_PERSONES   = in_ID_DEPARTAMENT_PERSONES;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END UPD_GVM_DEPARTAMENT_PERSONES;

  PROCEDURE DEL_GVM_DEPARTAMENT_PERSONES
    (
     in_ID_DEPARTAMENT_PERSONES IN GVM_ADM.GVM_DEPARTAMENT_PERSONES.ID_DEPARTAMENT_PERSONES%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'DEL_GVM_DEPARTAMENT_PERSONES';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='';
  
    DELETE FROM GVM_ADM.GVM_DEPARTAMENT_PERSONES
    WHERE
        ID_DEPARTAMENT_PERSONES   = in_ID_DEPARTAMENT_PERSONES;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END DEL_GVM_DEPARTAMENT_PERSONES;

END DML_GVM_DEPARTAMENT_PERSONES;
/
SHOW ERRORS;