Prompt drop Package Body DML_GVM_LOG_HISTORIC;
DROP PACKAGE BODY GVM_ADM.DML_GVM_LOG_HISTORIC
/

Prompt Package Body DML_GVM_LOG_HISTORIC;
--
-- DML_GVM_LOG_HISTORIC  (Package Body) 
--
--  Dependencies: 
--   DML_GVM_LOG_HISTORIC (Package)
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_LOG_HISTORIC (Table)
--   GVM_LOG_PROCEDIMENTS (Table)
--   DUAL (Synonym)
--   STANDARD (Package)
--
CREATE OR REPLACE PACKAGE BODY GVM_ADM.DML_GVM_LOG_HISTORIC IS

  PROCEDURE INS_GVM_LOG_HISTORIC
    (
     in_ID_LOG         IN GVM_ADM.GVM_LOG_HISTORIC.ID_LOG%TYPE
    ,in_NOM_TAULA      IN GVM_ADM.GVM_LOG_HISTORIC.NOM_TAULA%TYPE
    ,in_NOM_CAMP_TAULA IN GVM_ADM.GVM_LOG_HISTORIC.NOM_CAMP_TAULA%TYPE
    ,in_VALOR_ANTERIOR IN GVM_ADM.GVM_LOG_HISTORIC.VALOR_ANTERIOR%TYPE
    ,in_VALOR_ACTUAL   IN GVM_ADM.GVM_LOG_HISTORIC.VALOR_ACTUAL%TYPE
    ,in_TIPUS_OPERACIO IN GVM_ADM.GVM_LOG_HISTORIC.TIPUS_OPERACIO%TYPE
    ,in_DATA_ALTA      IN GVM_ADM.GVM_LOG_HISTORIC.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA IN GVM_ADM.GVM_LOG_HISTORIC.FK_USUARI_ALTA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'INS_GVM_LOG_HISTORIC';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    INSERT INTO GVM_ADM.GVM_LOG_HISTORIC
      (
       ID_LOG
      ,NOM_TAULA
      ,NOM_CAMP_TAULA
      ,VALOR_ANTERIOR
      ,VALOR_ACTUAL
      ,TIPUS_OPERACIO
      ,DATA_ALTA
      ,FK_USUARI_ALTA
      )
    VALUES
      (
       in_ID_LOG
      ,in_NOM_TAULA
      ,in_NOM_CAMP_TAULA
      ,in_VALOR_ANTERIOR
      ,in_VALOR_ACTUAL
      ,in_TIPUS_OPERACIO
      ,in_DATA_ALTA
      ,in_FK_USUARI_ALTA
      );
                   l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;     
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END INS_GVM_LOG_HISTORIC;

  PROCEDURE MERGE_GVM_LOG_HISTORIC
    (
     in_ID_LOG         IN GVM_ADM.GVM_LOG_HISTORIC.ID_LOG%TYPE
    ,in_NOM_TAULA      IN GVM_ADM.GVM_LOG_HISTORIC.NOM_TAULA%TYPE
    ,in_NOM_CAMP_TAULA IN GVM_ADM.GVM_LOG_HISTORIC.NOM_CAMP_TAULA%TYPE
    ,in_VALOR_ANTERIOR IN GVM_ADM.GVM_LOG_HISTORIC.VALOR_ANTERIOR%TYPE
    ,in_VALOR_ACTUAL   IN GVM_ADM.GVM_LOG_HISTORIC.VALOR_ACTUAL%TYPE
    ,in_TIPUS_OPERACIO IN GVM_ADM.GVM_LOG_HISTORIC.TIPUS_OPERACIO%TYPE
    ,in_DATA_ALTA      IN GVM_ADM.GVM_LOG_HISTORIC.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA IN GVM_ADM.GVM_LOG_HISTORIC.FK_USUARI_ALTA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'MERGE_GVM_LOG_HISTORIC';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    MERGE INTO GVM_ADM.GVM_LOG_HISTORIC A USING
      (SELECT
       in_ID_LOG as ID_LOG
      ,in_NOM_TAULA as NOM_TAULA
      ,in_NOM_CAMP_TAULA as NOM_CAMP_TAULA
      ,in_VALOR_ANTERIOR as VALOR_ANTERIOR
      ,in_VALOR_ACTUAL as VALOR_ACTUAL
      ,in_TIPUS_OPERACIO as TIPUS_OPERACIO
      ,in_DATA_ALTA as DATA_ALTA
      ,in_FK_USUARI_ALTA as FK_USUARI_ALTA
      FROM DUAL) B
    ON (A.ID_LOG= B.ID_LOG)
    WHEN NOT MATCHED THEN
      INSERT (
       ID_LOG
      ,NOM_TAULA
      ,NOM_CAMP_TAULA
      ,VALOR_ANTERIOR
      ,VALOR_ACTUAL
      ,TIPUS_OPERACIO
      ,DATA_ALTA
      ,FK_USUARI_ALTA)
      VALUES
      (in_ID_LOG
      ,in_NOM_TAULA
      ,in_NOM_CAMP_TAULA
      ,in_VALOR_ANTERIOR
      ,in_VALOR_ACTUAL
      ,in_TIPUS_OPERACIO
      ,in_DATA_ALTA
      ,in_FK_USUARI_ALTA)
    WHEN MATCHED THEN
      UPDATE SET
         A.NOM_TAULA = B.NOM_TAULA
        ,A.NOM_CAMP_TAULA = B.NOM_CAMP_TAULA
        ,A.VALOR_ANTERIOR = B.VALOR_ANTERIOR
        ,A.VALOR_ACTUAL = B.VALOR_ACTUAL
        ,A.TIPUS_OPERACIO = B.TIPUS_OPERACIO
        ,A.DATA_ALTA = B.DATA_ALTA
        ,A.FK_USUARI_ALTA = B.FK_USUARI_ALTA;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END MERGE_GVM_LOG_HISTORIC;

  PROCEDURE UPD_GVM_LOG_HISTORIC
    (
     in_ID_LOG         IN GVM_ADM.GVM_LOG_HISTORIC.ID_LOG%TYPE
    ,in_NOM_TAULA      IN GVM_ADM.GVM_LOG_HISTORIC.NOM_TAULA%TYPE
    ,in_NOM_CAMP_TAULA IN GVM_ADM.GVM_LOG_HISTORIC.NOM_CAMP_TAULA%TYPE
    ,in_VALOR_ANTERIOR IN GVM_ADM.GVM_LOG_HISTORIC.VALOR_ANTERIOR%TYPE
    ,in_VALOR_ACTUAL   IN GVM_ADM.GVM_LOG_HISTORIC.VALOR_ACTUAL%TYPE
    ,in_TIPUS_OPERACIO IN GVM_ADM.GVM_LOG_HISTORIC.TIPUS_OPERACIO%TYPE
    ,in_DATA_ALTA      IN GVM_ADM.GVM_LOG_HISTORIC.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA IN GVM_ADM.GVM_LOG_HISTORIC.FK_USUARI_ALTA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'UPD_GVM_LOG_HISTORIC';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    UPDATE GVM_ADM.GVM_LOG_HISTORIC
    SET 
        NOM_TAULA        = in_NOM_TAULA
       ,NOM_CAMP_TAULA   = in_NOM_CAMP_TAULA
       ,VALOR_ANTERIOR   = in_VALOR_ANTERIOR
       ,VALOR_ACTUAL     = in_VALOR_ACTUAL
       ,TIPUS_OPERACIO   = in_TIPUS_OPERACIO
       ,DATA_ALTA        = in_DATA_ALTA
       ,FK_USUARI_ALTA   = in_FK_USUARI_ALTA
    WHERE
        ID_LOG           = in_ID_LOG;
                      l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;  
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;
        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END UPD_GVM_LOG_HISTORIC;

  PROCEDURE DEL_GVM_LOG_HISTORIC
    (
     in_ID_LOG         IN GVM_ADM.GVM_LOG_HISTORIC.ID_LOG%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'DEL_GVM_LOG_HISTORIC';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='';
  
    DELETE FROM GVM_ADM.GVM_LOG_HISTORIC
    WHERE
        ID_LOG           = in_ID_LOG;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END DEL_GVM_LOG_HISTORIC;

END DML_GVM_LOG_HISTORIC;
/
SHOW ERRORS;