Prompt drop Package Body DML_GVM_POLITIQUES_DEPARTAMENT;
DROP PACKAGE BODY GVM_ADM.DML_GVM_POLITIQUES_DEPARTAMENT
/

Prompt Package Body DML_GVM_POLITIQUES_DEPARTAMENT;
--
-- DML_GVM_POLITIQUES_DEPARTAMENT  (Package Body) 
--
--  Dependencies: 
--   DML_GVM_POLITIQUES_DEPARTAMENT (Package)
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   CALCULAR_INCOMPLIMENTS_DEPARTAMENT (Procedure)
--   CALCULAR_INCOMPLIMENTS_POLITICA (Procedure)
--   GVM_LOG_PROCEDIMENTS (Table)
--   GVM_POLITIQUES_DEPARTAMENT (Table)
--   DUAL (Synonym)
--   STANDARD (Package)
--
CREATE OR REPLACE PACKAGE BODY GVM_ADM.DML_GVM_POLITIQUES_DEPARTAMENT
IS
    PROCEDURE INS_GVM_POLITIQUES_DEPARTAMENT (
        in_ID_POLITIQUES_DEPARTAMENT   IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.ID_POLITIQUES_DEPARTAMENT%TYPE,
        in_FK_ID_POLITICA              IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_ID_POLITICA%TYPE,
        in_FK_ID_DEPARTAMENT           IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_ID_DEPARTAMENT%TYPE,
        in_NUM_INCOMPLIMENTS           IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.NUM_INCOMPLIMENTS%TYPE,
        in_DATA_ALTA                   IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.DATA_ALTA%TYPE,
        in_DATA_MODIFICACIO            IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.DATA_MODIFICACIO%TYPE,
        in_DATA_BAIXA                  IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.DATA_BAIXA%TYPE,
        in_FK_USUARI_ALTA              IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_USUARI_ALTA%TYPE,
        in_FK_USUARI_MODIFICACIO       IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_USUARI_MODIFICACIO%TYPE,
        in_FK_USUARI_BAIXA             IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_USUARI_BAIXA%TYPE,
        RSP                               OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE)
    IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
    BEGIN
        RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'INS_GVM_POLITIQUES_DEPARTAMENT';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;


        l_IN_PARAM_ENTRADA :=
               TO_CHAR (in_ID_POLITIQUES_DEPARTAMENT)
            || ','
            || TO_CHAR (in_FK_ID_POLITICA)
            || ','
            || TO_CHAR (in_FK_ID_DEPARTAMENT)
            || ','
            || TO_CHAR (in_NUM_INCOMPLIMENTS)
            || ','
            || TO_CHAR (in_DATA_ALTA)
            || ','
            || TO_CHAR (in_DATA_MODIFICACIO)
            || ','
            || TO_CHAR (in_FK_USUARI_ALTA)
            || ','
            || TO_CHAR (in_FK_USUARI_MODIFICACIO)
            || ','
            || TO_CHAR (in_DATA_BAIXA)
            || ','
            || TO_CHAR (in_FK_USUARI_BAIXA);


        INSERT INTO GVM_ADM.GVM_POLITIQUES_DEPARTAMENT (
                        ID_POLITIQUES_DEPARTAMENT,
                        FK_ID_POLITICA,
                        FK_ID_DEPARTAMENT,
                        NUM_INCOMPLIMENTS,
                        DATA_ALTA,
                        DATA_MODIFICACIO,
                        DATA_BAIXA,
                        FK_USUARI_ALTA,
                        FK_USUARI_MODIFICACIO,
                        FK_USUARI_BAIXA)
             VALUES (in_ID_POLITIQUES_DEPARTAMENT,
                     in_FK_ID_POLITICA,
                     in_FK_ID_DEPARTAMENT,
                     in_NUM_INCOMPLIMENTS,
                     in_DATA_ALTA,
                     in_DATA_MODIFICACIO,
                     in_DATA_BAIXA,
                     in_FK_USUARI_ALTA,
                     in_FK_USUARI_MODIFICACIO,
                     in_FK_USUARI_BAIXA);

        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);

        GVM_ADM.CALCULAR_INCOMPLIMENTS_DEPARTAMENT (RSP);
        GVM_ADM.CALCULAR_INCOMPLIMENTS_POLITICA (RSP);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
    END INS_GVM_POLITIQUES_DEPARTAMENT;

    PROCEDURE MERGE_GVM_POLITIQUES_DEPARTAMENT (
        in_ID_POLITIQUES_DEPARTAMENT   IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.ID_POLITIQUES_DEPARTAMENT%TYPE,
        in_FK_ID_POLITICA              IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_ID_POLITICA%TYPE,
        in_FK_ID_DEPARTAMENT           IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_ID_DEPARTAMENT%TYPE,
        in_NUM_INCOMPLIMENTS           IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.NUM_INCOMPLIMENTS%TYPE,
        in_DATA_ALTA                   IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.DATA_ALTA%TYPE,
        in_DATA_MODIFICACIO            IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.DATA_MODIFICACIO%TYPE,
        in_DATA_BAIXA                  IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.DATA_BAIXA%TYPE,
        in_FK_USUARI_ALTA              IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_USUARI_ALTA%TYPE,
        in_FK_USUARI_MODIFICACIO       IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_USUARI_MODIFICACIO%TYPE,
        in_FK_USUARI_BAIXA             IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_USUARI_BAIXA%TYPE,
        RSP                               OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE)
    IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
    BEGIN
        RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'MERGE_GVM_POLITIQUES_DEPARTAMENT';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :=
               TO_CHAR (in_ID_POLITIQUES_DEPARTAMENT)
            || ','
            || TO_CHAR (in_FK_ID_POLITICA)
            || ','
            || TO_CHAR (in_FK_ID_DEPARTAMENT)
            || ','
            || TO_CHAR (in_NUM_INCOMPLIMENTS)
            || ','
            || TO_CHAR (in_DATA_ALTA)
            || ','
            || TO_CHAR (in_DATA_MODIFICACIO)
            || ','
            || TO_CHAR (in_FK_USUARI_ALTA)
            || ','
            || TO_CHAR (in_FK_USUARI_MODIFICACIO)
            || ','
            || TO_CHAR (in_DATA_BAIXA)
            || ','
            || TO_CHAR (in_FK_USUARI_BAIXA);


        MERGE INTO GVM_ADM.GVM_POLITIQUES_DEPARTAMENT A
             USING (SELECT in_ID_POLITIQUES_DEPARTAMENT
                               AS ID_POLITIQUES_DEPARTAMENT,
                           in_FK_ID_POLITICA
                               AS FK_ID_POLITICA,
                           in_FK_ID_DEPARTAMENT
                               AS FK_ID_DEPARTAMENT,
                           in_NUM_INCOMPLIMENTS
                               AS NUM_INCOMPLIMENTS,
                           in_DATA_ALTA
                               AS DATA_ALTA,
                           in_DATA_MODIFICACIO
                               AS DATA_MODIFICACIO,
                           in_DATA_BAIXA
                               AS DATA_BAIXA,
                           in_FK_USUARI_ALTA
                               AS FK_USUARI_ALTA,
                           in_FK_USUARI_MODIFICACIO
                               AS FK_USUARI_MODIFICACIO,
                           in_FK_USUARI_BAIXA
                               AS FK_USUARI_BAIXA
                      FROM DUAL) B
                ON (A.ID_POLITIQUES_DEPARTAMENT = B.ID_POLITIQUES_DEPARTAMENT)
        WHEN NOT MATCHED
        THEN
            INSERT     (ID_POLITIQUES_DEPARTAMENT,
                        FK_ID_POLITICA,
                        FK_ID_DEPARTAMENT,
                        NUM_INCOMPLIMENTS,
                        DATA_ALTA,
                        DATA_MODIFICACIO,
                        DATA_BAIXA,
                        FK_USUARI_ALTA,
                        FK_USUARI_MODIFICACIO,
                        FK_USUARI_BAIXA)
                VALUES (in_ID_POLITIQUES_DEPARTAMENT,
                        in_FK_ID_POLITICA,
                        in_FK_ID_DEPARTAMENT,
                        in_NUM_INCOMPLIMENTS,
                        in_DATA_ALTA,
                        in_DATA_MODIFICACIO,
                        in_DATA_BAIXA,
                        in_FK_USUARI_ALTA,
                        in_FK_USUARI_MODIFICACIO,
                        in_FK_USUARI_BAIXA)
        WHEN MATCHED
        THEN
            UPDATE SET A.FK_ID_POLITICA = B.FK_ID_POLITICA,
                       A.FK_ID_DEPARTAMENT = B.FK_ID_DEPARTAMENT,
                       A.NUM_INCOMPLIMENTS = B.NUM_INCOMPLIMENTS,
                       A.DATA_ALTA = B.DATA_ALTA,
                       A.DATA_MODIFICACIO = B.DATA_MODIFICACIO,
                       A.DATA_BAIXA = B.DATA_BAIXA,
                       A.FK_USUARI_ALTA = B.FK_USUARI_ALTA,
                       A.FK_USUARI_MODIFICACIO = B.FK_USUARI_MODIFICACIO,
                       A.FK_USUARI_BAIXA = B.FK_USUARI_BAIXA;

        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);

        GVM_ADM.CALCULAR_INCOMPLIMENTS_DEPARTAMENT (RSP);
        GVM_ADM.CALCULAR_INCOMPLIMENTS_POLITICA (RSP);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
    END MERGE_GVM_POLITIQUES_DEPARTAMENT;

    PROCEDURE UPD_GVM_POLITIQUES_DEPARTAMENT (
        in_ID_POLITIQUES_DEPARTAMENT   IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.ID_POLITIQUES_DEPARTAMENT%TYPE,
        in_FK_ID_POLITICA              IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_ID_POLITICA%TYPE,
        in_FK_ID_DEPARTAMENT           IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_ID_DEPARTAMENT%TYPE,
        in_NUM_INCOMPLIMENTS           IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.NUM_INCOMPLIMENTS%TYPE,
        in_DATA_ALTA                   IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.DATA_ALTA%TYPE,
        in_DATA_MODIFICACIO            IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.DATA_MODIFICACIO%TYPE,
        in_DATA_BAIXA                  IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.DATA_BAIXA%TYPE,
        in_FK_USUARI_ALTA              IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_USUARI_ALTA%TYPE,
        in_FK_USUARI_MODIFICACIO       IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_USUARI_MODIFICACIO%TYPE,
        in_FK_USUARI_BAIXA             IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.FK_USUARI_BAIXA%TYPE,
        RSP                               OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE)
    IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
    BEGIN
        RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'UPD_GVM_POLITIQUES_DEPARTAMENT';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :=
               TO_CHAR (in_ID_POLITIQUES_DEPARTAMENT)
            || ','
            || TO_CHAR (in_FK_ID_POLITICA)
            || ','
            || TO_CHAR (in_FK_ID_DEPARTAMENT)
            || ','
            || TO_CHAR (in_NUM_INCOMPLIMENTS)
            || ','
            || TO_CHAR (in_DATA_ALTA)
            || ','
            || TO_CHAR (in_DATA_MODIFICACIO)
            || ','
            || TO_CHAR (in_FK_USUARI_ALTA)
            || ','
            || TO_CHAR (in_FK_USUARI_MODIFICACIO)
            || ','
            || TO_CHAR (in_DATA_BAIXA)
            || ','
            || TO_CHAR (in_FK_USUARI_BAIXA);


        UPDATE GVM_ADM.GVM_POLITIQUES_DEPARTAMENT
           SET FK_ID_POLITICA = in_FK_ID_POLITICA,
               FK_ID_DEPARTAMENT = in_FK_ID_DEPARTAMENT,
               NUM_INCOMPLIMENTS = in_NUM_INCOMPLIMENTS,
               DATA_ALTA = in_DATA_ALTA,
               DATA_MODIFICACIO = in_DATA_MODIFICACIO,
               DATA_BAIXA = in_DATA_BAIXA,
               FK_USUARI_ALTA = in_FK_USUARI_ALTA,
               FK_USUARI_MODIFICACIO = in_FK_USUARI_MODIFICACIO,
               FK_USUARI_BAIXA = in_FK_USUARI_BAIXA
         WHERE ID_POLITIQUES_DEPARTAMENT = in_ID_POLITIQUES_DEPARTAMENT;

        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.CALCULAR_INCOMPLIMENTS_DEPARTAMENT (RSP);
        GVM_ADM.CALCULAR_INCOMPLIMENTS_POLITICA (RSP);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
    END UPD_GVM_POLITIQUES_DEPARTAMENT;

    PROCEDURE DEL_GVM_POLITIQUES_DEPARTAMENT (
        in_ID_POLITIQUES_DEPARTAMENT   IN     GVM_ADM.GVM_POLITIQUES_DEPARTAMENT.ID_POLITIQUES_DEPARTAMENT%TYPE,
        RSP                               OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE)
    IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
    BEGIN
        RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'DEL_GVM_POLITIQUES_DEPARTAMENT';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA := TO_CHAR (in_ID_POLITIQUES_DEPARTAMENT);

        DELETE FROM GVM_ADM.GVM_POLITIQUES_DEPARTAMENT
              WHERE ID_POLITIQUES_DEPARTAMENT = in_ID_POLITIQUES_DEPARTAMENT;
        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);

        GVM_ADM.CALCULAR_INCOMPLIMENTS_DEPARTAMENT (RSP);
        GVM_ADM.CALCULAR_INCOMPLIMENTS_POLITICA (RSP);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
    END DEL_GVM_POLITIQUES_DEPARTAMENT;
END DML_GVM_POLITIQUES_DEPARTAMENT;
/
SHOW ERRORS;