Prompt drop Package Body DML_GVM_PROCES;
DROP PACKAGE BODY GVM_ADM.DML_GVM_PROCES
/

Prompt Package Body DML_GVM_PROCES;
--
-- DML_GVM_PROCES  (Package Body) 
--
--  Dependencies: 
--   DML_GVM_PROCES (Package)
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_LOG_PROCEDIMENTS (Table)
--   GVM_PROCES (Table)
--   DUAL (Synonym)
--   STANDARD (Package)
--
CREATE OR REPLACE PACKAGE BODY GVM_ADM.DML_GVM_PROCES IS

  PROCEDURE INS_GVM_PROCES
    (
     in_ID_PROCES             IN GVM_ADM.GVM_PROCES.ID_PROCES%TYPE
    ,in_NOM_PROCES            IN GVM_ADM.GVM_PROCES.NOM_PROCES%TYPE
    ,in_DESC_PROCES_CAT       IN GVM_ADM.GVM_PROCES.DESC_PROCES_CAT%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_PROCES.DATA_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_PROCES.DATA_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_PROCES.DATA_BAIXA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_PROCES.FK_USUARI_ALTA%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_PROCES.FK_USUARI_MODIFICACIO%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_PROCES.FK_USUARI_BAIXA%TYPE
    ,in_FK_TIPUS_PROCES       IN GVM_ADM.GVM_PROCES.FK_TIPUS_PROCES%TYPE
    ,in_DESC_PROCES_CAST      IN GVM_ADM.GVM_PROCES.DESC_PROCES_CAST%TYPE
    ,in_DESC_PROCES_ANG       IN GVM_ADM.GVM_PROCES.DESC_PROCES_ANG%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'INS_GVM_PROCES';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    INSERT INTO GVM_ADM.GVM_PROCES
      (
       ID_PROCES
      ,NOM_PROCES
      ,DESC_PROCES_CAT
      ,DATA_ALTA
      ,DATA_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_ALTA
      ,FK_USUARI_MODIFICACIO
      ,FK_USUARI_BAIXA
      ,FK_TIPUS_PROCES
      ,DESC_PROCES_CAST
      ,DESC_PROCES_ANG
      )
    VALUES
      (
       in_ID_PROCES
      ,in_NOM_PROCES
      ,in_DESC_PROCES_CAT
      ,in_DATA_ALTA
      ,in_DATA_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_ALTA
      ,in_FK_USUARI_MODIFICACIO
      ,in_FK_USUARI_BAIXA
      ,in_FK_TIPUS_PROCES
      ,in_DESC_PROCES_CAST
      ,in_DESC_PROCES_ANG
      );
                       l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE; 
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END INS_GVM_PROCES;

  PROCEDURE MERGE_GVM_PROCES
    (
     in_ID_PROCES             IN GVM_ADM.GVM_PROCES.ID_PROCES%TYPE
    ,in_NOM_PROCES            IN GVM_ADM.GVM_PROCES.NOM_PROCES%TYPE
    ,in_DESC_PROCES_CAT       IN GVM_ADM.GVM_PROCES.DESC_PROCES_CAT%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_PROCES.DATA_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_PROCES.DATA_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_PROCES.DATA_BAIXA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_PROCES.FK_USUARI_ALTA%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_PROCES.FK_USUARI_MODIFICACIO%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_PROCES.FK_USUARI_BAIXA%TYPE
    ,in_FK_TIPUS_PROCES       IN GVM_ADM.GVM_PROCES.FK_TIPUS_PROCES%TYPE
    ,in_DESC_PROCES_CAST      IN GVM_ADM.GVM_PROCES.DESC_PROCES_CAST%TYPE
    ,in_DESC_PROCES_ANG       IN GVM_ADM.GVM_PROCES.DESC_PROCES_ANG%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'MERGE_GVM_PROCES';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    MERGE INTO GVM_ADM.GVM_PROCES A USING
      (SELECT
       in_ID_PROCES as ID_PROCES
      ,in_NOM_PROCES as NOM_PROCES
      ,in_DESC_PROCES_CAT as DESC_PROCES_CAT
      ,in_DATA_ALTA as DATA_ALTA
      ,in_DATA_MODIFICACIO as DATA_MODIFICACIO
      ,in_DATA_BAIXA as DATA_BAIXA
      ,in_FK_USUARI_ALTA as FK_USUARI_ALTA
      ,in_FK_USUARI_MODIFICACIO as FK_USUARI_MODIFICACIO
      ,in_FK_USUARI_BAIXA as FK_USUARI_BAIXA
      ,in_FK_TIPUS_PROCES as FK_TIPUS_PROCES
      ,in_DESC_PROCES_CAST as DESC_PROCES_CAST
      ,in_DESC_PROCES_ANG as DESC_PROCES_ANG
      FROM DUAL) B
    ON (A.ID_PROCES= B.ID_PROCES)
    WHEN NOT MATCHED THEN
      INSERT (
       ID_PROCES
      ,NOM_PROCES
      ,DESC_PROCES_CAT
      ,DATA_ALTA
      ,DATA_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_ALTA
      ,FK_USUARI_MODIFICACIO
      ,FK_USUARI_BAIXA
      ,FK_TIPUS_PROCES
      ,DESC_PROCES_CAST
      ,DESC_PROCES_ANG)
      VALUES
      (in_ID_PROCES
      ,in_NOM_PROCES
      ,in_DESC_PROCES_CAT
      ,in_DATA_ALTA
      ,in_DATA_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_ALTA
      ,in_FK_USUARI_MODIFICACIO
      ,in_FK_USUARI_BAIXA
      ,in_FK_TIPUS_PROCES
      ,in_DESC_PROCES_CAST
      ,in_DESC_PROCES_ANG)
    WHEN MATCHED THEN
      UPDATE SET
         A.NOM_PROCES = B.NOM_PROCES
        ,A.DESC_PROCES_CAT = B.DESC_PROCES_CAT
        ,A.DATA_ALTA = B.DATA_ALTA
        ,A.DATA_MODIFICACIO = B.DATA_MODIFICACIO
        ,A.DATA_BAIXA = B.DATA_BAIXA
        ,A.FK_USUARI_ALTA = B.FK_USUARI_ALTA
        ,A.FK_USUARI_MODIFICACIO = B.FK_USUARI_MODIFICACIO
        ,A.FK_USUARI_BAIXA = B.FK_USUARI_BAIXA
        ,A.FK_TIPUS_PROCES = B.FK_TIPUS_PROCES
        ,A.DESC_PROCES_CAST = B.DESC_PROCES_CAST
        ,A.DESC_PROCES_ANG = B.DESC_PROCES_ANG;
                      l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;  
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END MERGE_GVM_PROCES;

  PROCEDURE UPD_GVM_PROCES
    (
     in_ID_PROCES             IN GVM_ADM.GVM_PROCES.ID_PROCES%TYPE
    ,in_NOM_PROCES            IN GVM_ADM.GVM_PROCES.NOM_PROCES%TYPE
    ,in_DESC_PROCES_CAT       IN GVM_ADM.GVM_PROCES.DESC_PROCES_CAT%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_PROCES.DATA_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_PROCES.DATA_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_PROCES.DATA_BAIXA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_PROCES.FK_USUARI_ALTA%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_PROCES.FK_USUARI_MODIFICACIO%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_PROCES.FK_USUARI_BAIXA%TYPE
    ,in_FK_TIPUS_PROCES       IN GVM_ADM.GVM_PROCES.FK_TIPUS_PROCES%TYPE
    ,in_DESC_PROCES_CAST      IN GVM_ADM.GVM_PROCES.DESC_PROCES_CAST%TYPE
    ,in_DESC_PROCES_ANG       IN GVM_ADM.GVM_PROCES.DESC_PROCES_ANG%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'UPD_GVM_PROCES';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    UPDATE GVM_ADM.GVM_PROCES
    SET 
        NOM_PROCES              = in_NOM_PROCES
       ,DESC_PROCES_CAT         = in_DESC_PROCES_CAT
       ,DATA_ALTA               = in_DATA_ALTA
       ,DATA_MODIFICACIO        = in_DATA_MODIFICACIO
       ,DATA_BAIXA              = in_DATA_BAIXA
       ,FK_USUARI_ALTA          = in_FK_USUARI_ALTA
       ,FK_USUARI_MODIFICACIO   = in_FK_USUARI_MODIFICACIO
       ,FK_USUARI_BAIXA         = in_FK_USUARI_BAIXA
       ,FK_TIPUS_PROCES         = in_FK_TIPUS_PROCES
       ,DESC_PROCES_CAST        = in_DESC_PROCES_CAST
       ,DESC_PROCES_ANG         = in_DESC_PROCES_ANG
    WHERE
        ID_PROCES               = in_ID_PROCES;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END UPD_GVM_PROCES;

  PROCEDURE DEL_GVM_PROCES
    (
     in_ID_PROCES             IN GVM_ADM.GVM_PROCES.ID_PROCES%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'DEL_GVM_PROCES';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='';
  
    DELETE FROM GVM_ADM.GVM_PROCES
    WHERE
        ID_PROCES               = in_ID_PROCES;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END DEL_GVM_PROCES;

END DML_GVM_PROCES;
/
SHOW ERRORS;