Prompt drop Package Body DML_GVM_USUARIS;
DROP PACKAGE BODY GVM_ADM.DML_GVM_USUARIS
/

Prompt Package Body DML_GVM_USUARIS;
--
-- DML_GVM_USUARIS  (Package Body) 
--
--  Dependencies: 
--   DML_GVM_USUARIS (Package)
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_LOG_PROCEDIMENTS (Table)
--   GVM_USUARIS (Table)
--   DUAL (Synonym)
--   STANDARD (Package)
--
CREATE OR REPLACE PACKAGE BODY GVM_ADM.DML_GVM_USUARIS IS

  PROCEDURE INS_GVM_USUARIS
    (
     in_ID_USUARI             IN GVM_ADM.GVM_USUARIS.ID_USUARI%TYPE
    ,in_NOM                   IN GVM_ADM.GVM_USUARIS.NOM%TYPE
    ,in_PRIMER_COGNOM         IN GVM_ADM.GVM_USUARIS.PRIMER_COGNOM%TYPE
    ,in_SEGON_COGNOM          IN GVM_ADM.GVM_USUARIS.SEGON_COGNOM%TYPE
    ,in_TIPUS_DOCUMENT        IN GVM_ADM.GVM_USUARIS.TIPUS_DOCUMENT%TYPE
    ,in_CODI_DOCUMENT         IN GVM_ADM.GVM_USUARIS.CODI_DOCUMENT%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_USUARIS.DATA_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_USUARIS.DATA_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_USUARIS.DATA_BAIXA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_USUARIS.FK_USUARI_ALTA%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_USUARIS.FK_USUARI_MODIFICACIO%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_USUARIS.FK_USUARI_BAIXA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'INS_GVM_USUARIS';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    INSERT INTO GVM_ADM.GVM_USUARIS
      (
       ID_USUARI
      ,NOM
      ,PRIMER_COGNOM
      ,SEGON_COGNOM
      ,TIPUS_DOCUMENT
      ,CODI_DOCUMENT
      ,DATA_ALTA
      ,DATA_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_ALTA
      ,FK_USUARI_MODIFICACIO
      ,FK_USUARI_BAIXA
      )
    VALUES
      (
       in_ID_USUARI
      ,in_NOM
      ,in_PRIMER_COGNOM
      ,in_SEGON_COGNOM
      ,in_TIPUS_DOCUMENT
      ,in_CODI_DOCUMENT
      ,in_DATA_ALTA
      ,in_DATA_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_ALTA
      ,in_FK_USUARI_MODIFICACIO
      ,in_FK_USUARI_BAIXA
      );
                      l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;  
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END INS_GVM_USUARIS;

  PROCEDURE MERGE_GVM_USUARIS
    (
     in_ID_USUARI             IN GVM_ADM.GVM_USUARIS.ID_USUARI%TYPE
    ,in_NOM                   IN GVM_ADM.GVM_USUARIS.NOM%TYPE
    ,in_PRIMER_COGNOM         IN GVM_ADM.GVM_USUARIS.PRIMER_COGNOM%TYPE
    ,in_SEGON_COGNOM          IN GVM_ADM.GVM_USUARIS.SEGON_COGNOM%TYPE
    ,in_TIPUS_DOCUMENT        IN GVM_ADM.GVM_USUARIS.TIPUS_DOCUMENT%TYPE
    ,in_CODI_DOCUMENT         IN GVM_ADM.GVM_USUARIS.CODI_DOCUMENT%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_USUARIS.DATA_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_USUARIS.DATA_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_USUARIS.DATA_BAIXA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_USUARIS.FK_USUARI_ALTA%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_USUARIS.FK_USUARI_MODIFICACIO%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_USUARIS.FK_USUARI_BAIXA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'MERGE_GVM_USUARIS';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    MERGE INTO GVM_ADM.GVM_USUARIS A USING
      (SELECT
       in_ID_USUARI as ID_USUARI
      ,in_NOM as NOM
      ,in_PRIMER_COGNOM as PRIMER_COGNOM
      ,in_SEGON_COGNOM as SEGON_COGNOM
      ,in_TIPUS_DOCUMENT as TIPUS_DOCUMENT
      ,in_CODI_DOCUMENT as CODI_DOCUMENT
      ,in_DATA_ALTA as DATA_ALTA
      ,in_DATA_MODIFICACIO as DATA_MODIFICACIO
      ,in_DATA_BAIXA as DATA_BAIXA
      ,in_FK_USUARI_ALTA as FK_USUARI_ALTA
      ,in_FK_USUARI_MODIFICACIO as FK_USUARI_MODIFICACIO
      ,in_FK_USUARI_BAIXA as FK_USUARI_BAIXA
      FROM DUAL) B
    ON (A.ID_USUARI= B.ID_USUARI)
    WHEN NOT MATCHED THEN
      INSERT (
       ID_USUARI
      ,NOM
      ,PRIMER_COGNOM
      ,SEGON_COGNOM
      ,TIPUS_DOCUMENT
      ,CODI_DOCUMENT
      ,DATA_ALTA
      ,DATA_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_ALTA
      ,FK_USUARI_MODIFICACIO
      ,FK_USUARI_BAIXA)
      VALUES
      (in_ID_USUARI
      ,in_NOM
      ,in_PRIMER_COGNOM
      ,in_SEGON_COGNOM
      ,in_TIPUS_DOCUMENT
      ,in_CODI_DOCUMENT
      ,in_DATA_ALTA
      ,in_DATA_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_ALTA
      ,in_FK_USUARI_MODIFICACIO
      ,in_FK_USUARI_BAIXA)
    WHEN MATCHED THEN
      UPDATE SET
         A.NOM = B.NOM
        ,A.PRIMER_COGNOM = B.PRIMER_COGNOM
        ,A.SEGON_COGNOM = B.SEGON_COGNOM
        ,A.TIPUS_DOCUMENT = B.TIPUS_DOCUMENT
        ,A.CODI_DOCUMENT = B.CODI_DOCUMENT
        ,A.DATA_ALTA = B.DATA_ALTA
        ,A.DATA_MODIFICACIO = B.DATA_MODIFICACIO
        ,A.DATA_BAIXA = B.DATA_BAIXA
        ,A.FK_USUARI_ALTA = B.FK_USUARI_ALTA
        ,A.FK_USUARI_MODIFICACIO = B.FK_USUARI_MODIFICACIO
        ,A.FK_USUARI_BAIXA = B.FK_USUARI_BAIXA;
                    l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;    
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END MERGE_GVM_USUARIS;

  PROCEDURE UPD_GVM_USUARIS
    (
     in_ID_USUARI             IN GVM_ADM.GVM_USUARIS.ID_USUARI%TYPE
    ,in_NOM                   IN GVM_ADM.GVM_USUARIS.NOM%TYPE
    ,in_PRIMER_COGNOM         IN GVM_ADM.GVM_USUARIS.PRIMER_COGNOM%TYPE
    ,in_SEGON_COGNOM          IN GVM_ADM.GVM_USUARIS.SEGON_COGNOM%TYPE
    ,in_TIPUS_DOCUMENT        IN GVM_ADM.GVM_USUARIS.TIPUS_DOCUMENT%TYPE
    ,in_CODI_DOCUMENT         IN GVM_ADM.GVM_USUARIS.CODI_DOCUMENT%TYPE
    ,in_DATA_ALTA             IN GVM_ADM.GVM_USUARIS.DATA_ALTA%TYPE
    ,in_DATA_MODIFICACIO      IN GVM_ADM.GVM_USUARIS.DATA_MODIFICACIO%TYPE
    ,in_DATA_BAIXA            IN GVM_ADM.GVM_USUARIS.DATA_BAIXA%TYPE
    ,in_FK_USUARI_ALTA        IN GVM_ADM.GVM_USUARIS.FK_USUARI_ALTA%TYPE
    ,in_FK_USUARI_MODIFICACIO IN GVM_ADM.GVM_USUARIS.FK_USUARI_MODIFICACIO%TYPE
    ,in_FK_USUARI_BAIXA       IN GVM_ADM.GVM_USUARIS.FK_USUARI_BAIXA%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'UPD_GVM_USUARIS';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
        l_IN_PARAM_ENTRADA :='';
  
    UPDATE GVM_ADM.GVM_USUARIS
    SET 
        NOM                     = in_NOM
       ,PRIMER_COGNOM           = in_PRIMER_COGNOM
       ,SEGON_COGNOM            = in_SEGON_COGNOM
       ,TIPUS_DOCUMENT          = in_TIPUS_DOCUMENT
       ,CODI_DOCUMENT           = in_CODI_DOCUMENT
       ,DATA_ALTA               = in_DATA_ALTA
       ,DATA_MODIFICACIO        = in_DATA_MODIFICACIO
       ,DATA_BAIXA              = in_DATA_BAIXA
       ,FK_USUARI_ALTA          = in_FK_USUARI_ALTA
       ,FK_USUARI_MODIFICACIO   = in_FK_USUARI_MODIFICACIO
       ,FK_USUARI_BAIXA         = in_FK_USUARI_BAIXA
    WHERE
        ID_USUARI               = in_ID_USUARI;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END UPD_GVM_USUARIS;

  PROCEDURE DEL_GVM_USUARIS
    (
     in_ID_USUARI             IN GVM_ADM.GVM_USUARIS.ID_USUARI%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'DEL_GVM_USUARIS';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='';
  
    DELETE FROM GVM_ADM.GVM_USUARIS
    WHERE
        ID_USUARI               = in_ID_USUARI;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END DEL_GVM_USUARIS;

END DML_GVM_USUARIS;
/
SHOW ERRORS;