/*
Proces de clcul d'estadistiques per la CONSULTA 8: Percentatge dusuaris de lempresa que, en lany en curs, no tenen cap incompliment assignat. 
*/
Prompt drop Procedure CALCULAR_ESTADISTIQUES_EMPRESA_OK;
DROP PROCEDURE GVM_ADM.CALCULAR_ESTADISTIQUES_EMPRESA_OK
/

Prompt Procedure CALCULAR_ESTADISTIQUES_EMPRESA_OK;
--
-- CALCULAR_ESTADISTIQUES_EMPRESA_OK  (Procedure) 
--
--  Dependencies: 
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_CALCUL_ESTADISTIQUES_EMPRESA_OK (Table)
--   GVM_DEPARTAMENT_PERSONES (Table)
--   GVM_LOG_PROCEDIMENTS (Table)
--   GVM_SESSIONS_FORMACIO (Table)
--   GVM_SESSIO_USUARI (Table)
--   STANDARD (Package)
--   SYS_STUB_FOR_PURITY_ANALYSIS (Package)
--
CREATE OR REPLACE PROCEDURE GVM_ADM.calcular_estadistiques_empresa_ok (
    RSP   OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE)
IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
    BEGIN
        RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'calcular_estadistiques_empresa_ok';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='';

    DELETE FROM GVM_CALCUL_ESTADISTIQUES_EMPRESA_OK;

    --COMMIT;

    INSERT INTO GVM_CALCUL_ESTADISTIQUES_EMPRESA_OK
        (SELECT any_actual,
                total_ok,
                total_persones_departament,
                total_ok / total_persones_departament     percentage
           FROM (  SELECT any_actual,
                          COUNT (*)     total_ok,
                          total_persones_departament
                     FROM (SELECT DISTINCT
                                  usu.fk_id_usuari,
                                  TO_NUMBER (TO_CHAR (fo.data_inici, 'YYYY'))
                                      any_actual,
                                  (SELECT COUNT (DISTINCT FK_ID_PERSONA)
                                     FROM GVM_DEPARTAMENT_PERSONES)
                                      total_persones_departament
                             FROM GVM_SESSIONS_FORMACIO fo,
                                  GVM_SESSIO_USUARI    usu
                            WHERE     fo.ID_SESSIO = usu.fk_id_Sessio
                                  AND usu.estat_sessio = 1)
                 GROUP BY any_actual, total_persones_departament));



    --COMMIT;

    RSP := 'ok';


  
        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;

        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
  RETURN;                                      
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);    
END;
/
SHOW ERRORS;