/*
Proces de clcul d'estadistiques per la CONSULTA 6: Poltica de seguretat que, en el moment de fer la consulta, ha tingut ms incompliments (tenint en compte tots els departament de lempresa)
*/
Prompt drop Procedure CALCULAR_INCOMPLIMENTS_DEPARTAMENT_ANY;
DROP PROCEDURE GVM_ADM.CALCULAR_INCOMPLIMENTS_DEPARTAMENT_ANY
/

Prompt Procedure CALCULAR_INCOMPLIMENTS_DEPARTAMENT_ANY;
--
-- CALCULAR_INCOMPLIMENTS_DEPARTAMENT_ANY  (Procedure) 
--
--  Dependencies: 
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_LOG_PROCEDIMENTS (Table)
--   GVM_POLITIQUES_DEPARTAMENT (Table)
--   GVM_POLITIQUES_SEGURETAT (Table)
--   DBMS_OUTPUT (Synonym)
--   STANDARD (Package)
--   SYS_STUB_FOR_PURITY_ANALYSIS (Package)
--
CREATE OR REPLACE PROCEDURE GVM_ADM.calcular_incompliments_departament_any (
    p_any   IN     NUMBER,
    RSP        OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE)
IS
    --p_resultat varchar(500);
    max_incompliments   NUMBER;
    n_departament       NUMBER;
    n_politiques        NUMBER;
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
    BEGIN
        RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'calcular_incompliments_departament_any';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='';

    --GVM_POLITIQUES_DEPARTAMENT
    --GVM_SESSIO_USUARI
    --GVM_MOSTREIG
    --GVM_VULNERABILITATS

    max_incompliments := 0;
    n_departament := 0;
    n_politiques := 0;

    IF (   p_any IS NULL
        OR p_any < 2000
        OR p_any > TO_NUMBER (TO_CHAR (SYSDATE, 'YYYY')))
    THEN
        RSP := 'any incorrecte';

        RETURN;
    ELSE
        SELECT MAX (num_incompliments)
          INTO max_incompliments
          FROM GVM_POLITIQUES_DEPARTAMENT
         WHERE fk_id_politica IN (SELECT id_politica
                                    FROM GVM_POLITIQUES_SEGURETAT
                                   WHERE any_alta_politica = p_any);

        SELECT COUNT (FK_ID_DEPARTAMENT)
          INTO n_departament
          FROM (SELECT DISTINCT FK_ID_DEPARTAMENT
                  FROM GVM_POLITIQUES_DEPARTAMENT
                 WHERE     fk_id_politica IN
                               (SELECT id_politica
                                  FROM GVM_POLITIQUES_SEGURETAT
                                 WHERE any_alta_politica = p_any)
                       AND num_incompliments = max_incompliments);

        SELECT COUNT (fk_id_politica)
          INTO n_politiques
          FROM (SELECT DISTINCT fk_id_politica
                  FROM GVM_POLITIQUES_DEPARTAMENT
                 WHERE     fk_id_politica IN
                               (SELECT id_politica
                                  FROM GVM_POLITIQUES_SEGURETAT
                                 WHERE any_alta_politica = p_any)
                       AND num_incompliments = max_incompliments);

        --dbms_output.put_line( r_product.product_name ||         ': $' ||         r_product.list_price );
        DBMS_OUTPUT.put_line (
            'num maxims incompliments:' || max_incompliments);
        DBMS_OUTPUT.put_line ('num total de departaments:' || n_departament);
        DBMS_OUTPUT.put_line ('num total de politiques:' || n_politiques);

        FOR r_politica
            IN (SELECT DISTINCT fk_id_politica
                  FROM GVM_POLITIQUES_DEPARTAMENT
                 WHERE     fk_id_politica IN
                               (SELECT id_politica
                                  FROM GVM_POLITIQUES_SEGURETAT
                                 WHERE any_alta_politica = p_any)
                       AND num_incompliments = max_incompliments)
        LOOP
            FOR r_departament
                IN (SELECT FK_ID_DEPARTAMENT, num_incompliments
                      FROM GVM_POLITIQUES_DEPARTAMENT
                     WHERE     fk_id_politica = r_politica.fk_id_politica
                           AND num_incompliments = max_incompliments)
            LOOP
                RSP :=
                       RSP
                    || ' el departament/s: '
                    || r_departament.FK_ID_DEPARTAMENT
                    || ' amb ms incomplements : '
                    || r_departament.num_incompliments
                    || ' a l''any: '
                    || p_any
                    || ' per la politica: '
                    || r_politica.fk_id_politica;
            END LOOP;
        END LOOP;

        --COMMIT;

       


        
    END IF;

        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;

        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
                                      
RETURN;                                      

    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
END;
/
SHOW ERRORS;