/*
Proces de clcul d'estadistiques per la CONSULTA 14: Tenint en compte totes les accions de mitigaci en estat en procs, persona responsable amb ms accions assignades.
*/
Prompt drop Procedure CALCULAR_MITIGACIO_RESPONSABLE;
DROP PROCEDURE GVM_ADM.CALCULAR_MITIGACIO_RESPONSABLE
/

Prompt Procedure CALCULAR_MITIGACIO_RESPONSABLE;
--
-- CALCULAR_MITIGACIO_RESPONSABLE  (Procedure) 
--
--  Dependencies: 
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_ACCIONS_MITIGACIO (Table)
--   GVM_CALCUL_TOTAL_MITIGACIO_RESPONSABLE (Table)
--   GVM_LOG_PROCEDIMENTS (Table)
--   STANDARD (Package)
--   SYS_STUB_FOR_PURITY_ANALYSIS (Package)
--
CREATE OR REPLACE PROCEDURE GVM_ADM.calcular_mitigacio_responsable (
    RSP   OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE)
IS
    total_mitigacions_estat_proces_usuari   NUMBER;
    total_mitigacions_estat_proces          NUMBER;
    total_mitigacions                       NUMBER;
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
    BEGIN
        RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'calcular_mitigacio_responsable';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='NO APLICA';

    total_mitigacions := 0;
    total_mitigacions_estat_proces := 0;
    total_mitigacions_estat_proces_usuari := 0;

    SELECT COUNT (*) INTO total_mitigacions FROM GVM_ACCIONS_MITIGACIO;

    SELECT COUNT (*)
      INTO total_mitigacions_estat_proces
      FROM GVM_ACCIONS_MITIGACIO
     WHERE fk_estat_mitigacio = 2;

    SELECT MAX (total)
      INTO total_mitigacions_estat_proces_usuari
      FROM (  SELECT FK_ID_USUARI_RESPONSABLE, COUNT (*) total
                FROM GVM_ACCIONS_MITIGACIO
               WHERE fk_estat_mitigacio = 2
            GROUP BY FK_ID_USUARI_RESPONSABLE);



    DELETE FROM GVM_CALCUL_TOTAL_MITIGACIO_RESPONSABLE;

    --COMMIT;


    INSERT INTO GVM_ADM.GVM_CALCUL_TOTAL_MITIGACIO_RESPONSABLE
        (SELECT total_mitigacions,
                total_mitigacions_estat_proces,
                FK_ID_USUARI_RESPONSABLE,
                total
           FROM (  SELECT FK_ID_USUARI_RESPONSABLE, COUNT (*) total
                     FROM GVM_ACCIONS_MITIGACIO
                    WHERE fk_estat_mitigacio = 2
                 GROUP BY FK_ID_USUARI_RESPONSABLE)
          WHERE total = total_mitigacions_estat_proces_usuari);

    --COMMIT;

    RSP := 'ok';

        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;

        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    RETURN;

    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);    
END;
/
SHOW ERRORS;