Prompt drop Package Body DML_GVM_VULNERABILITATS;
DROP PACKAGE BODY GVM_ADM.DML_GVM_VULNERABILITATS
/

Prompt Package Body DML_GVM_VULNERABILITATS;
--
-- DML_GVM_VULNERABILITATS  (Package Body) 
--
--  Dependencies: 
--   DML_GVM_VULNERABILITATS (Package)
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   CALCULAR_ESTADISTIQUES_VULNERABILITATS (Procedure)
--   CALCULAR_INCOMPLIMENTS_PROCES (Procedure)
--   CALCULAR_PERCENTATGE_VULNERABILITAT_CRIT (Procedure)
--   CALCULAR_TOTAL_VULNERABILITATS_CRITIQUES (Procedure)
--   GVM_LOG_PROCEDIMENTS (Table)
--   GVM_VULNERABILITATS (Table)
--   DUAL (Synonym)
--   STANDARD (Package)
--
CREATE OR REPLACE PACKAGE BODY GVM_ADM.DML_GVM_VULNERABILITATS IS

  PROCEDURE INS_GVM_VULNERABILITATS
    (
     in_ID_VULNERABILITAT       IN GVM_ADM.GVM_VULNERABILITATS.ID_VULNERABILITAT%TYPE
    ,in_FK_ESTAT_VULNERABILITAT IN GVM_ADM.GVM_VULNERABILITATS.FK_ESTAT_VULNERABILITAT%TYPE
    ,in_FK_NIVELL_CRITICITAT    IN GVM_ADM.GVM_VULNERABILITATS.FK_NIVELL_CRITICITAT%TYPE
    ,in_DATA_ALTA               IN GVM_ADM.GVM_VULNERABILITATS.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA          IN GVM_ADM.GVM_VULNERABILITATS.FK_USUARI_ALTA%TYPE
    ,in_DATA_MODIFICACIO        IN GVM_ADM.GVM_VULNERABILITATS.DATA_MODIFICACIO%TYPE
    ,in_FK_USUARI_MODIFICACIO   IN GVM_ADM.GVM_VULNERABILITATS.FK_USUARI_MODIFICACIO%TYPE
    ,in_DATA_BAIXA              IN GVM_ADM.GVM_VULNERABILITATS.DATA_BAIXA%TYPE
    ,in_FK_USUARI_BAIXA         IN GVM_ADM.GVM_VULNERABILITATS.FK_USUARI_BAIXA%TYPE
    ,in_FK_PROCES_ORIGEN        IN GVM_ADM.GVM_VULNERABILITATS.FK_PROCES_ORIGEN%TYPE
    ,in_ORIGEN                  IN GVM_ADM.GVM_VULNERABILITATS.ORIGEN%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'INS_GVM_VULNERABILITATS';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
   
        
 l_IN_PARAM_ENTRADA :=
               TO_CHAR (in_ID_VULNERABILITAT)
            || ','
            || TO_CHAR (in_FK_ESTAT_VULNERABILITAT)
            || ','
            || TO_CHAR (in_FK_NIVELL_CRITICITAT)
            || ','
            || TO_CHAR (in_DATA_ALTA)
            || ','
            || TO_CHAR (in_DATA_MODIFICACIO)
            || ','
            || TO_CHAR (in_FK_USUARI_ALTA)
            || ','
            || TO_CHAR (in_FK_USUARI_MODIFICACIO)
            || ','
            || TO_CHAR (in_DATA_BAIXA)
            || ','
            || TO_CHAR (in_FK_USUARI_BAIXA)
            || ','
            || TO_CHAR (in_FK_PROCES_ORIGEN)
            || ','                        
            || TO_CHAR (in_ORIGEN);        
  
    INSERT INTO GVM_ADM.GVM_VULNERABILITATS
      (
       ID_VULNERABILITAT
      ,FK_ESTAT_VULNERABILITAT
      ,FK_NIVELL_CRITICITAT
      ,DATA_ALTA
      ,FK_USUARI_ALTA
      ,DATA_MODIFICACIO
      ,FK_USUARI_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_BAIXA
      ,FK_PROCES_ORIGEN
      ,ORIGEN
      )
    VALUES
      (
       in_ID_VULNERABILITAT
      ,in_FK_ESTAT_VULNERABILITAT
      ,in_FK_NIVELL_CRITICITAT
      ,in_DATA_ALTA
      ,in_FK_USUARI_ALTA
      ,in_DATA_MODIFICACIO
      ,in_FK_USUARI_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_BAIXA
      ,in_FK_PROCES_ORIGEN
      ,in_ORIGEN
      );
                l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;        
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    

GVM_ADM.calcular_incompliments_proces (RSP); 
GVM_ADM.calcular_estadistiques_vulnerabilitats (RSP); 
GVM_ADM.calcular_percentatge_vulnerabilitat_crit (RSP); 
GVM_ADM.calcular_total_vulnerabilitats_critiques (RSP); 

                          
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END INS_GVM_VULNERABILITATS;

  PROCEDURE MERGE_GVM_VULNERABILITATS
    (
     in_ID_VULNERABILITAT       IN GVM_ADM.GVM_VULNERABILITATS.ID_VULNERABILITAT%TYPE
    ,in_FK_ESTAT_VULNERABILITAT IN GVM_ADM.GVM_VULNERABILITATS.FK_ESTAT_VULNERABILITAT%TYPE
    ,in_FK_NIVELL_CRITICITAT    IN GVM_ADM.GVM_VULNERABILITATS.FK_NIVELL_CRITICITAT%TYPE
    ,in_DATA_ALTA               IN GVM_ADM.GVM_VULNERABILITATS.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA          IN GVM_ADM.GVM_VULNERABILITATS.FK_USUARI_ALTA%TYPE
    ,in_DATA_MODIFICACIO        IN GVM_ADM.GVM_VULNERABILITATS.DATA_MODIFICACIO%TYPE
    ,in_FK_USUARI_MODIFICACIO   IN GVM_ADM.GVM_VULNERABILITATS.FK_USUARI_MODIFICACIO%TYPE
    ,in_DATA_BAIXA              IN GVM_ADM.GVM_VULNERABILITATS.DATA_BAIXA%TYPE
    ,in_FK_USUARI_BAIXA         IN GVM_ADM.GVM_VULNERABILITATS.FK_USUARI_BAIXA%TYPE
    ,in_FK_PROCES_ORIGEN        IN GVM_ADM.GVM_VULNERABILITATS.FK_PROCES_ORIGEN%TYPE
    ,in_ORIGEN                  IN GVM_ADM.GVM_VULNERABILITATS.ORIGEN%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'MERGE_GVM_VULNERABILITATS';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
 l_IN_PARAM_ENTRADA :=
               TO_CHAR (in_ID_VULNERABILITAT)
            || ','
            || TO_CHAR (in_FK_ESTAT_VULNERABILITAT)
            || ','
            || TO_CHAR (in_FK_NIVELL_CRITICITAT)
            || ','
            || TO_CHAR (in_DATA_ALTA)
            || ','
            || TO_CHAR (in_DATA_MODIFICACIO)
            || ','
            || TO_CHAR (in_FK_USUARI_ALTA)
            || ','
            || TO_CHAR (in_FK_USUARI_MODIFICACIO)
            || ','
            || TO_CHAR (in_DATA_BAIXA)
            || ','
            || TO_CHAR (in_FK_USUARI_BAIXA)
            || ','
            || TO_CHAR (in_FK_PROCES_ORIGEN)
            || ','                        
            || TO_CHAR (in_ORIGEN);             
  
    MERGE INTO GVM_ADM.GVM_VULNERABILITATS A USING
      (SELECT
       in_ID_VULNERABILITAT as ID_VULNERABILITAT
      ,in_FK_ESTAT_VULNERABILITAT as FK_ESTAT_VULNERABILITAT
      ,in_FK_NIVELL_CRITICITAT as FK_NIVELL_CRITICITAT
      ,in_DATA_ALTA as DATA_ALTA
      ,in_FK_USUARI_ALTA as FK_USUARI_ALTA
      ,in_DATA_MODIFICACIO as DATA_MODIFICACIO
      ,in_FK_USUARI_MODIFICACIO as FK_USUARI_MODIFICACIO
      ,in_DATA_BAIXA as DATA_BAIXA
      ,in_FK_USUARI_BAIXA as FK_USUARI_BAIXA
      ,in_FK_PROCES_ORIGEN as FK_PROCES_ORIGEN
      ,in_ORIGEN as ORIGEN
      FROM DUAL) B
    ON (A.ID_VULNERABILITAT= B.ID_VULNERABILITAT)
    WHEN NOT MATCHED THEN
      INSERT (
       ID_VULNERABILITAT
      ,FK_ESTAT_VULNERABILITAT
      ,FK_NIVELL_CRITICITAT
      ,DATA_ALTA
      ,FK_USUARI_ALTA
      ,DATA_MODIFICACIO
      ,FK_USUARI_MODIFICACIO
      ,DATA_BAIXA
      ,FK_USUARI_BAIXA
      ,FK_PROCES_ORIGEN
      ,ORIGEN)
      VALUES
      (in_ID_VULNERABILITAT
      ,in_FK_ESTAT_VULNERABILITAT
      ,in_FK_NIVELL_CRITICITAT
      ,in_DATA_ALTA
      ,in_FK_USUARI_ALTA
      ,in_DATA_MODIFICACIO
      ,in_FK_USUARI_MODIFICACIO
      ,in_DATA_BAIXA
      ,in_FK_USUARI_BAIXA
      ,in_FK_PROCES_ORIGEN
      ,in_ORIGEN)
    WHEN MATCHED THEN
      UPDATE SET
         A.FK_ESTAT_VULNERABILITAT = B.FK_ESTAT_VULNERABILITAT
        ,A.FK_NIVELL_CRITICITAT = B.FK_NIVELL_CRITICITAT
        ,A.DATA_ALTA = B.DATA_ALTA
        ,A.FK_USUARI_ALTA = B.FK_USUARI_ALTA
        ,A.DATA_MODIFICACIO = B.DATA_MODIFICACIO
        ,A.FK_USUARI_MODIFICACIO = B.FK_USUARI_MODIFICACIO
        ,A.DATA_BAIXA = B.DATA_BAIXA
        ,A.FK_USUARI_BAIXA = B.FK_USUARI_BAIXA
        ,A.FK_PROCES_ORIGEN = B.FK_PROCES_ORIGEN
        ,A.ORIGEN = B.ORIGEN;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
GVM_ADM.calcular_incompliments_proces (RSP); 
GVM_ADM.calcular_estadistiques_vulnerabilitats (RSP); 
GVM_ADM.calcular_percentatge_vulnerabilitat_crit (RSP); 
GVM_ADM.calcular_total_vulnerabilitats_critiques (RSP);                                 
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END MERGE_GVM_VULNERABILITATS;

  PROCEDURE UPD_GVM_VULNERABILITATS
    (
     in_ID_VULNERABILITAT       IN GVM_ADM.GVM_VULNERABILITATS.ID_VULNERABILITAT%TYPE
    ,in_FK_ESTAT_VULNERABILITAT IN GVM_ADM.GVM_VULNERABILITATS.FK_ESTAT_VULNERABILITAT%TYPE
    ,in_FK_NIVELL_CRITICITAT    IN GVM_ADM.GVM_VULNERABILITATS.FK_NIVELL_CRITICITAT%TYPE
    ,in_DATA_ALTA               IN GVM_ADM.GVM_VULNERABILITATS.DATA_ALTA%TYPE
    ,in_FK_USUARI_ALTA          IN GVM_ADM.GVM_VULNERABILITATS.FK_USUARI_ALTA%TYPE
    ,in_DATA_MODIFICACIO        IN GVM_ADM.GVM_VULNERABILITATS.DATA_MODIFICACIO%TYPE
    ,in_FK_USUARI_MODIFICACIO   IN GVM_ADM.GVM_VULNERABILITATS.FK_USUARI_MODIFICACIO%TYPE
    ,in_DATA_BAIXA              IN GVM_ADM.GVM_VULNERABILITATS.DATA_BAIXA%TYPE
    ,in_FK_USUARI_BAIXA         IN GVM_ADM.GVM_VULNERABILITATS.FK_USUARI_BAIXA%TYPE
    ,in_FK_PROCES_ORIGEN        IN GVM_ADM.GVM_VULNERABILITATS.FK_PROCES_ORIGEN%TYPE
    ,in_ORIGEN                  IN GVM_ADM.GVM_VULNERABILITATS.ORIGEN%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'UPD_GVM_VULNERABILITATS';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := in_FK_USUARI_ALTA;
 l_IN_PARAM_ENTRADA :=
               TO_CHAR (in_ID_VULNERABILITAT)
            || ','
            || TO_CHAR (in_FK_ESTAT_VULNERABILITAT)
            || ','
            || TO_CHAR (in_FK_NIVELL_CRITICITAT)
            || ','
            || TO_CHAR (in_DATA_ALTA)
            || ','
            || TO_CHAR (in_DATA_MODIFICACIO)
            || ','
            || TO_CHAR (in_FK_USUARI_ALTA)
            || ','
            || TO_CHAR (in_FK_USUARI_MODIFICACIO)
            || ','
            || TO_CHAR (in_DATA_BAIXA)
            || ','
            || TO_CHAR (in_FK_USUARI_BAIXA)
            || ','
            || TO_CHAR (in_FK_PROCES_ORIGEN)
            || ','                        
            || TO_CHAR (in_ORIGEN);             
  
    UPDATE GVM_ADM.GVM_VULNERABILITATS
    SET 
        FK_ESTAT_VULNERABILITAT   = in_FK_ESTAT_VULNERABILITAT
       ,FK_NIVELL_CRITICITAT      = in_FK_NIVELL_CRITICITAT
       ,DATA_ALTA                 = in_DATA_ALTA
       ,FK_USUARI_ALTA            = in_FK_USUARI_ALTA
       ,DATA_MODIFICACIO          = in_DATA_MODIFICACIO
       ,FK_USUARI_MODIFICACIO     = in_FK_USUARI_MODIFICACIO
       ,DATA_BAIXA                = in_DATA_BAIXA
       ,FK_USUARI_BAIXA           = in_FK_USUARI_BAIXA
       ,FK_PROCES_ORIGEN          = in_FK_PROCES_ORIGEN
       ,ORIGEN                    = in_ORIGEN
    WHERE
        ID_VULNERABILITAT         = in_ID_VULNERABILITAT;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
GVM_ADM.calcular_incompliments_proces (RSP); 
GVM_ADM.calcular_estadistiques_vulnerabilitats (RSP); 
GVM_ADM.calcular_percentatge_vulnerabilitat_crit (RSP); 
GVM_ADM.calcular_total_vulnerabilitats_critiques (RSP);                               
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END UPD_GVM_VULNERABILITATS;

  PROCEDURE DEL_GVM_VULNERABILITATS
    (
     in_ID_VULNERABILITAT       IN GVM_ADM.GVM_VULNERABILITATS.ID_VULNERABILITAT%TYPE,
    RSP OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE
    ) IS
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
  BEGIN   
  RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'DEL_GVM_VULNERABILITATS';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
 l_IN_PARAM_ENTRADA :=
               TO_CHAR (in_ID_VULNERABILITAT);
  
    DELETE FROM GVM_ADM.GVM_VULNERABILITATS
    WHERE
        ID_VULNERABILITAT         = in_ID_VULNERABILITAT;
                        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;
        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
                                      
GVM_ADM.calcular_incompliments_proces (RSP); 
GVM_ADM.calcular_estadistiques_vulnerabilitats (RSP); 
GVM_ADM.calcular_percentatge_vulnerabilitat_crit (RSP); 
GVM_ADM.calcular_total_vulnerabilitats_critiques (RSP);                               
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
  END DEL_GVM_VULNERABILITATS;

END DML_GVM_VULNERABILITATS;
/
SHOW ERRORS;