/*
Proces de clcul d'estadistiques per la CONSULTA 4: Percentatge de vulnerabilitats que, en el moment de fer la consulta, estan totalment mitigades.
*/
Prompt drop Procedure CALCULAR_ESTADISTIQUES_VULNERABILITATS;
DROP PROCEDURE GVM_ADM.CALCULAR_ESTADISTIQUES_VULNERABILITATS
/

Prompt Procedure CALCULAR_ESTADISTIQUES_VULNERABILITATS;
--
-- CALCULAR_ESTADISTIQUES_VULNERABILITATS  (Procedure) 
--
--  Dependencies: 
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_CALCUL_ESTADISTIQUES_VULNERABILITATS (Table)
--   GVM_LOG_PROCEDIMENTS (Table)
--   GVM_VULNERABILITATS (Table)
--   STANDARD (Package)
--   SYS_STUB_FOR_PURITY_ANALYSIS (Package)
--
CREATE OR REPLACE PROCEDURE GVM_ADM.calcular_estadistiques_vulnerabilitats (
    RSP   OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE)
IS
    --p_resultat varchar(500);
    n_total_vulnerabilitats   NUMBER;
    n_estat_1                 NUMBER;
    n_estat_2                 NUMBER;
    n_estat_3                 NUMBER;
    n_estat_4                 NUMBER;
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
    BEGIN
        RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'calcular_estadistiques_vulnerabilitats';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='';

    n_total_vulnerabilitats := 0;
    n_estat_1 := 0;
    n_estat_2 := 0;
    n_estat_3 := 0;
    n_estat_4 := 0;

    DELETE FROM GVM_CALCUL_ESTADISTIQUES_VULNERABILITATS;

    SELECT COUNT (*) INTO n_total_vulnerabilitats FROM GVM_VULNERABILITATS;

    SELECT COUNT (*)
      INTO n_estat_1
      FROM GVM_VULNERABILITATS
     WHERE fk_Estat_vulnerabilitat = 1;

    SELECT COUNT (*)
      INTO n_estat_2
      FROM GVM_VULNERABILITATS
     WHERE fk_Estat_vulnerabilitat = 2;

    SELECT COUNT (*)
      INTO n_estat_3
      FROM GVM_VULNERABILITATS
     WHERE fk_Estat_vulnerabilitat = 3;

    SELECT COUNT (*)
      INTO n_estat_4
      FROM GVM_VULNERABILITATS
     WHERE fk_Estat_vulnerabilitat = 4;

    INSERT INTO GVM_ADM.GVM_CALCUL_ESTADISTIQUES_VULNERABILITATS (
                    TOTAL_VULNERABILITATS,
                    TOTAL_ESTAT_1,
                    TOTAL_ESTAT_2,
                    TOTAL_ESTAT_3,
                    TOTAL_ESTAT_4,
                    PERCENTATGE_1,
                    PERCENTATGE_2,
                    PERCENTATGE_3,
                    PERCENTATGE_4)
         VALUES (                                  /* TOTAL_VULNERABILITATS */
                 n_total_vulnerabilitats,
                 /* TOTAL_ESTAT_1 */
                 n_estat_1,
                 /* TOTAL_ESTAT_2 */
                 n_estat_2,
                 /* TOTAL_ESTAT_3 */
                 n_estat_3,
                 /* TOTAL_ESTAT_4 */
                 n_estat_4,
                 /* PERCENTATGE_1 */
                 n_estat_1 / n_total_vulnerabilitats,
                 /* PERCENTATGE_2 */
                 n_estat_2 / n_total_vulnerabilitats,
                 /* PERCENTATGE_3 */
                 n_estat_3 / n_total_vulnerabilitats,
                 /* PERCENTATGE_4 */
                 n_estat_4 / n_total_vulnerabilitats);

    --COMMIT;

    RSP := 'ok';




        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;

        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    RETURN;
                                          
    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);
END;
/
SHOW ERRORS;