/*
Proces de clcul d'estadistiques per la CONSULTA 10: Percentatge de vulnerabilitats crtiques que, en el moment de fer la consulta, tenen alguna acci de mitigaci oberta (que no estigui en estat acabada).
*/
Prompt drop Procedure CALCULAR_PERCENTATGE_VULNERABILITAT_CRIT;
DROP PROCEDURE GVM_ADM.CALCULAR_PERCENTATGE_VULNERABILITAT_CRIT
/

Prompt Procedure CALCULAR_PERCENTATGE_VULNERABILITAT_CRIT;
--
-- CALCULAR_PERCENTATGE_VULNERABILITAT_CRIT  (Procedure) 
--
--  Dependencies: 
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_ACCIONS_MITIGACIO (Table)
--   GVM_CALCUL_ESTADISTIQUES_VULNERABILITAT_MITIGADES (Table)
--   GVM_LOG_PROCEDIMENTS (Table)
--   GVM_VULNERABILITATS (Table)
--   STANDARD (Package)
--   SYS_STUB_FOR_PURITY_ANALYSIS (Package)
--
CREATE OR REPLACE PROCEDURE GVM_ADM.calcular_percentatge_vulnerabilitat_crit (
    RSP   OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE)
IS
    total_critiques             NUMBER;
    total_critiques_mitigades   NUMBER;
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
    BEGIN
        RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'calcular_percentatge_vulnerabilitat_crit';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='NO APLICA';

    total_critiques := 0;
    total_critiques_mitigades := 0;

    DELETE FROM GVM_CALCUL_ESTADISTIQUES_VULNERABILITAT_MITIGADES;

    --COMMIT;

    SELECT COUNT (*)
      INTO total_critiques
      FROM GVM_VULNERABILITATS
     WHERE FK_NIVELL_CRITICITAT = 1;

    SELECT COUNT (id_vulnerabilitat)
      INTO total_critiques_mitigades
      FROM GVM_VULNERABILITATS
     WHERE     FK_NIVELL_CRITICITAT = 1     --and FK_ESTAT_VULNERABILITAT <> 4
           AND id_vulnerabilitat NOT IN (SELECT fk_id_vulnerabilitat
                                           FROM GVM_ACCIONS_MITIGACIO
                                          WHERE fk_estat_mitigacio <> 3);


    INSERT INTO GVM_ADM.GVM_CALCUL_ESTADISTIQUES_VULNERABILITAT_MITIGADES (
                    TOTAL_VULNERAB_CRITIC,
                    TOTAL_VULNERAB_CRITIC_MITIGAR,
                    PERCENTATGE_VULNERAB_CRITIC_MITIGAR)
             VALUES (                              /* TOTAL_VULNERAB_CRITIC */
                     total_critiques,
                     /* TOTAL_VULNERAB_CRITIC_MITIGAR */
                     total_critiques_mitigades,
                     /* PERCENTATGE_VULNERAB_CRITIC_MITIGAR */
                     (total_critiques_mitigades / total_critiques));

    --COMMIT;

    RSP := 'ok';

        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;

        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
                                      
    RETURN;

    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);    
END;
/
SHOW ERRORS;