/*
Proces de clcul d'estadistiques per la CONSULTA 12: Nmero de vulnerabilitats crtiques detectades internament tenint en compte totes les dades de que es disposa. Es consideren detectades internament si es van detectar en posterioritat a lanlisi fet inicialment per la consultora externa.
*/
Prompt drop Procedure CALCULAR_TOTAL_VULNERABILITATS_CRITIQUES;
DROP PROCEDURE GVM_ADM.CALCULAR_TOTAL_VULNERABILITATS_CRITIQUES
/

Prompt Procedure CALCULAR_TOTAL_VULNERABILITATS_CRITIQUES;
--
-- CALCULAR_TOTAL_VULNERABILITATS_CRITIQUES  (Procedure) 
--
--  Dependencies: 
--   ALTA_LOG_PROCEDIMENT (Procedure)
--   GVM_CALCUL_TOTAL_VULNERABILITATS_CRITIQUES (Table)
--   GVM_LOG_PROCEDIMENTS (Table)
--   GVM_VULNERABILITATS (Table)
--   STANDARD (Package)
--   SYS_STUB_FOR_PURITY_ANALYSIS (Package)
--
CREATE OR REPLACE PROCEDURE GVM_ADM.calcular_total_vulnerabilitats_critiques (
    RSP   OUT GVM_ADM.GVM_LOG_PROCEDIMENTS.PARAM_SORTIDA%TYPE)
IS
    total_critiques_internes   NUMBER;
    total_critiques_externes   NUMBER;
    total_critiques            NUMBER;
        l_IN_NOM_PROCEDIMENT     VARCHAR2 (100);
        l_IN_DATA_INICI          DATE;
        l_IN_DATA_FI             DATE;
        l_IN_PARAM_ENTRADA       VARCHAR2 (1200);
        l_IN_PARAM_SORTIDA       VARCHAR2 (1200);
        l_IN_RESULTAT_EXECUCIO   NUMBER;
        l_IN_USUARI_ALTA         NUMBER;
    BEGIN
        RSP := 'OK';
        l_IN_NOM_PROCEDIMENT := 'calcular_total_vulnerabilitats_critiques';
        l_IN_DATA_INICI := SYSDATE;
        l_IN_RESULTAT_EXECUCIO := 0;
        l_IN_USUARI_ALTA := 1;
        l_IN_PARAM_ENTRADA :='';

    total_critiques := 0;
    total_critiques_internes := 0;
    total_critiques_externes := 0;

    SELECT COUNT (*)
      INTO total_critiques
      FROM (SELECT DISTINCT fk_proces_origen
              FROM GVM_VULNERABILITATS
             WHERE fk_nivell_criticitat = 1                        --critiques
                                           );

    SELECT COUNT (*)
      INTO total_critiques_internes
      FROM (SELECT DISTINCT fk_proces_origen
              FROM GVM_VULNERABILITATS
             WHERE fk_nivell_criticitat = 1 AND origen = 0 --interna i critiques
                                                          );

    SELECT COUNT (*)
      INTO total_critiques_externes
      FROM (SELECT DISTINCT fk_proces_origen
              FROM GVM_VULNERABILITATS
             WHERE fk_nivell_criticitat = 1 AND origen = 1 --externes i critiques
                                                          );

    DELETE FROM GVM_CALCUL_TOTAL_VULNERABILITATS_CRITIQUES;

    --COMMIT;


    INSERT INTO GVM_ADM.GVM_CALCUL_TOTAL_VULNERABILITATS_CRITIQUES
             VALUES (total_critiques,
                     total_critiques_internes,
                     total_critiques_externes);

    --COMMIT;

    RSP := 'ok';

        l_IN_PARAM_SORTIDA := RSP;
        l_IN_DATA_FI := SYSDATE;

        GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                      l_IN_DATA_INICI,
                                      l_IN_DATA_FI,
                                      l_IN_PARAM_ENTRADA,
                                      l_IN_PARAM_SORTIDA,
                                      l_IN_RESULTAT_EXECUCIO,
                                      l_IN_USUARI_ALTA);
    RETURN;

    EXCEPTION
        --Per qualsevol altra excepci
        WHEN OTHERS
        THEN
            --Guarda el error a RSP
            RSP := 'ERROR' || ':' || SQLERRM;
            l_IN_PARAM_SORTIDA := RSP;
            l_IN_RESULTAT_EXECUCIO := 1;
            l_IN_DATA_FI := SYSDATE;

            --Crea el log amb el nom del procediment, parmetres i variable d'error
            GVM_ADM.ALTA_LOG_PROCEDIMENT (l_IN_NOM_PROCEDIMENT,
                                          l_IN_DATA_INICI,
                                          l_IN_DATA_FI,
                                          l_IN_PARAM_ENTRADA,
                                          l_IN_PARAM_SORTIDA,
                                          l_IN_RESULTAT_EXECUCIO,
                                          l_IN_USUARI_ALTA);    
END;
/
SHOW ERRORS;